package org.apache.jyve.actions;

/*
 * Copyright (c) 1997-1999 The Java Apache Project.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. All advertising materials mentioning features or use of this
 *    software must display the following acknowledgment:
 *    "This product includes software developed by the Java Apache
 *    Project for use in the Apache JServ servlet engine project
 *    <http://java.apache.org/>."
 *
 * 4. The names "Apache JServ", "Apache JServ Servlet Engine", "Jyve",
 *    "Apache Jyve", "Jyve Project", "Apache Jyve Project" and
 *    "Java Apache Project" must not be used to endorse or promote products
 *    derived from this software without prior written permission.
 *
 * 5. Products derived from this software may not be called "Apache JServ"
 *    nor may "Apache" nor "Apache JServ" appear in their names without
 *    prior written permission of the Java Apache Project.
 *
 * 6. Redistributions of any form whatsoever must retain the following
 *    acknowledgment:
 *    "This product includes software developed by the Java Apache
 *    Project for use in the Apache JServ servlet engine project
 *    <http://java.apache.org/>."
 *
 * THIS SOFTWARE IS PROVIDED BY THE JAVA APACHE PROJECT "AS IS" AND ANY
 * EXPRESSED OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE JAVA APACHE PROJECT OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Java Apache Group. For more information
 * on the Java Apache Project and the Apache JServ Servlet Engine project,
 * please see <http://java.apache.org/>.
 *
 */

// JDK Stuff
import java.io.*;
import java.sql.*;
import java.util.Hashtable;

// Servlet Stuff
import javax.servlet.*;
import javax.servlet.http.*;

// External Stuff
import org.apache.jyve.util.*;
import org.apache.turbine.modules.*;
import org.apache.turbine.services.*;
import org.apache.turbine.services.localization.*;
import org.apache.turbine.util.*;
import org.apache.turbine.om.security.*;
import org.apache.turbine.util.db.*;
import org.apache.turbine.util.db.pool.*;
import com.workingdogs.village.*;
import org.apache.ecs.*;
import org.apache.ecs.html.*;

/**
*/
public class AddNewProject extends Action
{
    public void doPerform( RunData data ) throws Exception
    {
        // check to see if the Cancel button was pressed.
        // if so, return to the homepage
        String submit = "submit1";
        String str = (String) data.getUser().getTemp ( submit, "asdfasdf" );
        if ( str != null && str
            .equalsIgnoreCase( data.parameters.getString(submit, "")) )
        {
            data.getUser().removeTemp(submit);
            return;            
        }

        // Security check. This feature was added at 26.01.2000
        // by Bernie Hoeneisen, ETH Zurich, mailto:bhoeneis@ee.ethz.ch
        // last modified: 22.02.2000 (bernie)
        // failScreen = currentScreen
        JSecurityCheck secCheck = new JSecurityCheck(data,
            Localization.getString("ADDNEWPRJ_NOADDPERM"), 
            data.getScreen() );
        if ( !secCheck.accessToActionAddNew("project"))
        {
            data.getUser().removeTemp(submit);
            return;
        }

        // get a connection to the db
        DBConnection db = DBBroker.getInstance().getConnection();
        Connection connection = db.getConnection();

        // execute the query
        TableDataSet tds = new TableDataSet( connection, "project" );
        try
        {
            Record rec = tds.addRecord();
            rec.setValue ( "project_value", data.parameters.getString("project_value",
                Localization.getString("ADDNEWPRJ_UNTITLEDPRJ")) );
            rec.setValue ( "display_order", data.parameters.getInt("display_order", 0) );
            int id = data.getUser().getId();
            if ( id == -1 )
                id = 1;
            rec.setValue ( "visitorid", id );
 
            if ( secCheck.permissionToAddReleased("project") )
            {
                rec.setValue ( "released", "Y" );
                rec.setValue ( "released_date", new java.util.Date() );
                rec.setValue ( "released_by", id ); // 'id' is 'visitorid'
            }
            else
            {
                rec.setValue ( "released", "N" );
            }

            rec.save();            
        }
        finally
        {
            if ( tds != null ) tds.close();
            DBBroker.getInstance().releaseConnection(db);
        }
        data.setMessage (Localization.getString("ADDNEWPRJ_CREATE"));
    }
}
