package org.apache.jyve.actions;
 
/*
 * Copyright (c) 1997-1999 The Java Apache Project.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. All advertising materials mentioning features or use of this
 *    software must display the following acknowledgment:
 *    "This product includes software developed by the Java Apache
 *    Project for use in the Apache JServ servlet engine project
 *    <http://java.apache.org/>."
 *
 * 4. The names "Apache JServ", "Apache JServ Servlet Engine", "Jyve",
 *    "Apache Jyve", "Jyve Project", "Apache Jyve Project" and
 *    "Java Apache Project" must not be used to endorse or promote products
 *    derived from this software without prior written permission.
 *
 * 5. Products derived from this software may not be called "Apache JServ"
 *    nor may "Apache" nor "Apache JServ" appear in their names without
 *    prior written permission of the Java Apache Project.
 *
 * 6. Redistributions of any form whatsoever must retain the following
 *    acknowledgment:
 *    "This product includes software developed by the Java Apache
 *    Project for use in the Apache JServ servlet engine project
 *    <http://java.apache.org/>."
 *
 * THIS SOFTWARE IS PROVIDED BY THE JAVA APACHE PROJECT "AS IS" AND ANY
 * EXPRESSED OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE JAVA APACHE PROJECT OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Java Apache Group. For more information
 * on the Java Apache Project and the Apache JServ Servlet Engine project,
 * please see <http://java.apache.org/>.
 *
 */

// JDK Stuff
import java.io.*;
import java.sql.*;
import java.util.*;

// Servlet Stuff
import javax.servlet.*;
import javax.servlet.http.*;

// External Stuff
import org.apache.turbine.modules.*;
import org.apache.turbine.services.localization.Localization;
import org.apache.turbine.services.resources.TurbineResources;
import org.apache.turbine.util.*;
import org.apache.turbine.om.security.*;
import org.apache.turbine.om.user.*;
import org.apache.turbine.om.user.peer.*;
import org.apache.turbine.util.db.*;
import org.apache.turbine.util.db.pool.*;
import com.workingdogs.village.*;
import org.apache.ecs.*;
import org.apache.ecs.html.*;

/**
    This action validates the form input from the NewAccount Screen. 
    If it is valid, then it will check to make sure that the user account 
    does not already exist. If it does, then it will show the NewAccount 
    screen again. If it doesn't alread exist, then it will create the new 
    user and set the CONFIRM_VALUE to be the users session id. This part should 
    probably be re-done to get a better less hackable CONFIRM_VALUE, but this 
    should work for now. If everything goes well, this action will send the user
    a confirmation email and then show the ConfirmRegistration screen.
    
    @author Jon S. Stevens <a href="mailto:jon@clearink.com">jon@clearink.com</a>
*/
public class CreateNewUserAndConfirm extends Action
{
    public void doPerform( RunData data ) throws Exception
    {
        String submit = "submit1";
        String str = (String) data.getUser().getTemp ( submit, "asdfasdf" );
        if ( str != null && str
            .equalsIgnoreCase( data.getParameters().getString(submit, "")) )
        {
            data.getUser().removeTemp(submit);
            data.setScreen ( TurbineResources.getString("screen.homepage") );
            return;            
        }
        
        String pass1 = data.getParameters().getString("password", "");
        String pass2 = data.getParameters().getString("password_confirm", "");        
        // make sure the passwords are not empty
        if ( (pass1.length() == 0 || pass2.length() == 0 )
            || ! pass1.equals ( pass2 ) )
        {
            data.setMessage(Localization.getString("CREATENEWUSERANDCONFIRM_PWNOTMATCH"));
            data.setScreen("NewAccount");
            return;
        }
        
        String username = data.getParameters().getString("username", "");
        // make sure the username exists
        if ( username.length() == 0 )
        {
            data.setMessage(Localization.getString("CREATENEWUSERANDCONFIRM_NOUSERNAME"));
            data.setScreen("NewAccount");
            return;
        }            
        String email = data.getParameters().getString("email", "");
        // make sure the email exists
        if ( email.length() == 0 )
        {
            data.setMessage(Localization.getString("CREATENEWUSERANDCONFIRM_NOEMAIL"));
            data.setScreen("NewAccount");
            return;
        }

        String CHNAME = "Choose another name.";
      
        // Make sure that the user doesn't already exist
        // and that the username is not the CHNAME string
        Criteria testcrit = new Criteria();
        testcrit.add ( TurbineUserPeer.getColumnName("LOGINID"), username );        
        Vector output = TurbineUserPeer.doSelect(testcrit);

        // if the username does not already exist, then we are all good!
        if ((output == null || output.size() == 0) && ! username.equalsIgnoreCase(CHNAME))
        {
            // get a connection to the db
            DBConnection db = DBBroker.getInstance().getConnection();
            Connection connection = db.getConnection();

            // execute the query
            TableDataSet tds = new TableDataSet( connection, TurbineUserPeer.getTableName() );
            try
            {
                Record rec = tds.addRecord();
                rec.setValue ( "PASSWORD_VALUE", data.getParameters().getString("password") );
                rec.setValue ( "LOGINID", username );
                rec.setValue ( "FIRST_NAME", data.getParameters().getString("firstname") );
                rec.setValue ( "LAST_NAME", data.getParameters().getString("lastname") );
                rec.setValue ( "EMAIL", data.getParameters().getString("email") );
                rec.setValue ( "CREATED", new java.util.Date() );
                rec.setValue ( "CONFIRM_VALUE", GenerateUniqueId.getIdentifier() );
                rec.save();
                data.setMessage(Localization.getString("CREATENEWUSERANDCONFIRM_CREATE"));

                ActionLoader.getInstance().exec(data, "SendConfirmationEmail");
            }
            finally
            {
                if ( tds != null ) tds.close();
                DBBroker.getInstance().releaseConnection(db);
            }
        }
        else // username exists. show the screen again.
        {
            data.setMessage(Localization.getString("CREATENEWUSERANDCONFIRM_CHOOSENEWNAME"));
            data.setScreen("NewAccount");
            // set the username to be the CHNAME string so that it is 
            // clear that this needs to be replaced
            data.getParameters().add("username", CHNAME);
        }
    }
}
