package org.apache.jyve.actions;

/*
 * Copyright (c) 1997-1999 The Java Apache Project.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. All advertising materials mentioning features or use of this
 *    software must display the following acknowledgment:
 *    "This product includes software developed by the Java Apache
 *    Project for use in the Apache JServ servlet engine project
 *    <http://java.apache.org/>."
 *
 * 4. The names "Apache JServ", "Apache JServ Servlet Engine", "Jyve",
 *    "Apache Jyve", "Jyve Project", "Apache Jyve Project" and
 *    "Java Apache Project" must not be used to endorse or promote products
 *    derived from this software without prior written permission.
 *
 * 5. Products derived from this software may not be called "Apache JServ"
 *    nor may "Apache" nor "Apache JServ" appear in their names without
 *    prior written permission of the Java Apache Project.
 *
 * 6. Redistributions of any form whatsoever must retain the following
 *    acknowledgment:
 *    "This product includes software developed by the Java Apache
 *    Project for use in the Apache JServ servlet engine project
 *    <http://java.apache.org/>."
 *
 * THIS SOFTWARE IS PROVIDED BY THE JAVA APACHE PROJECT "AS IS" AND ANY
 * EXPRESSED OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE JAVA APACHE PROJECT OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Java Apache Group. For more information
 * on the Java Apache Project and the Apache JServ Servlet Engine project,
 * please see <http://java.apache.org/>.
 *
 */

// JDK Stuff
import java.io.*;
import java.sql.*;
import java.util.Hashtable;

// Servlet Stuff
import javax.servlet.*;
import javax.servlet.http.*;

// External Stuff
import org.apache.turbine.modules.*;
import org.apache.turbine.services.*;
import org.apache.turbine.services.localization.*;
import org.apache.turbine.util.*;
import org.apache.turbine.om.security.*;
import org.apache.turbine.util.db.*;
import org.apache.turbine.util.db.pool.*;
import com.workingdogs.village.*;
import org.apache.ecs.*;
import org.apache.ecs.html.*;

/**
    This action marks an question as deleted. It updated the modified_by as well as the 
    deleted_by to be the person who did the action.
*/
public class DeleteQuestion extends Action
{
    public void doPerform( RunData data ) throws Exception
    {
        // Security check. This feature was added at 26.01.2000
        // by Bernie Hoeneisen, ETH Zurich, mailto:bhoeneis@ee.ethz.ch
        // failScreen = currentScreen
        SecurityCheck secCheck = new SecurityCheck(data, 
            Localization.getString("DELETEQUESTION_NOMODIFYPERM"), 
            data.getScreen() );
        if ( !secCheck.hasPermission("modify_question"))
        {
            return;
        }

        Integer question_id = (Integer) data.getUser().getTemp("question_id", new Integer(-1));
        if ( question_id == null || question_id.intValue() == -1 )
        {
            data.setMessage(Localization.getString("DELETEQUESTION_NOVALIDSELECTION"));
            data.setScreen ( "DisplayOneTopic" );
            return;
        }
        
        // get a connection to the db
        DBConnection db = DBBroker.getInstance().getConnection();
        Connection connection = db.getConnection();

        // execute the query
        KeyDef kd = new KeyDef().addAttrib("question_id");
        TableDataSet tds = new TableDataSet( connection, "question", kd );
        tds.where ( "question_id=" + question_id );
        try
        {
            tds.fetchRecords(1);
            if ( tds.size() == 1 )
            {
                Record rec = tds.getRecord(0);
                rec.setValue ( "deleted", "Y" );
                int id = data.getUser().getId();
                if ( id == -1 )
                    id = 1;
                rec.setValue ( "modified_by", id );
                rec.setValue ( "deleted_by", id );
                rec.setValue ( "modified_date", new java.util.Date() );
                rec.save();
            }
            else
            {
                data.setMessage(Localization.getString("DELETEQUESTION_NOTFOUND"));
            }
        }
        finally
        {
            if ( tds != null ) tds.close();
            DBBroker.getInstance().releaseConnection(db);
        }
        
        data.setMessage (Localization.getString("DELETEQUESTION_DELETED"));
    }
}