package org.apache.jyve.actions;

/*
 * Copyright (c) 1997-1999 The Java Apache Project.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. All advertising materials mentioning features or use of this
 *    software must display the following acknowledgment:
 *    "This product includes software developed by the Java Apache
 *    Project for use in the Apache JServ servlet engine project
 *    <http://java.apache.org/>."
 *
 * 4. The names "Apache JServ", "Apache JServ Servlet Engine", "Jyve",
 *    "Apache Jyve", "Jyve Project", "Apache Jyve Project" and
 *    "Java Apache Project" must not be used to endorse or promote products
 *    derived from this software without prior written permission.
 *
 * 5. Products derived from this software may not be called "Apache JServ"
 *    nor may "Apache" nor "Apache JServ" appear in their names without
 *    prior written permission of the Java Apache Project.
 *
 * 6. Redistributions of any form whatsoever must retain the following
 *    acknowledgment:
 *    "This product includes software developed by the Java Apache
 *    Project for use in the Apache JServ servlet engine project
 *    <http://java.apache.org/>."
 *
 * THIS SOFTWARE IS PROVIDED BY THE JAVA APACHE PROJECT "AS IS" AND ANY
 * EXPRESSED OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE JAVA APACHE PROJECT OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Java Apache Group. For more information
 * on the Java Apache Project and the Apache JServ Servlet Engine project,
 * please see <http://java.apache.org/>.
 *
 */
 
// Java Core Classes
import java.io.*;
import java.sql.*;
import java.util.*;

// Java Servlet Classes
import javax.servlet.*;
import javax.servlet.http.*;

// Turbine Modules
import org.apache.turbine.modules.*;
import org.apache.turbine.services.*;
import org.apache.turbine.services.localization.*;
import org.apache.turbine.util.*;
import org.apache.turbine.om.security.*;
import org.apache.turbine.om.security.peer.*;
import org.apache.turbine.om.user.*;
import org.apache.turbine.om.user.peer.*;
import org.apache.turbine.util.db.*;
import org.apache.turbine.util.db.pool.*;
import com.workingdogs.village.*;
import org.apache.ecs.*;
import org.apache.ecs.html.*;

/**
    This class is responsible for logging a user into the system. It is also
    responsible for making sure that the user has been marked as confirmed. 
    If the user is not marked as confirmed, then it will show them the 
    
*/
public class JLoginUser extends Action
{
    /** this is the value that is stored in the database for confirmed users */
    private static final String CONFIRM_VALUE = "CONFIRMED";
    
    public void doPerform( RunData data ) throws Exception
    {
        // we are on the ConfirmRegistration page
        String secretkey = (String) data.getParameters().getString("secretkey", null);
        if ( secretkey != null )
        {
            // handle the buttons on the ConfirmRegistration page
            String button1 = data.getParameters().getString ( "submit1", null );
            if ( button1 != null && button1.equalsIgnoreCase("Cancel") )
            {
                data.setScreen ("MainMenu");
                return;
            }
            
            // get a connection to the db
            DBConnection db = DBBroker.getInstance().getConnection();
            Connection connection = db.getConnection();
            // execute the query
            String username = data.parameters.getString("username", "");
            KeyDef kd = new KeyDef().addAttrib("loginid");
            TableDataSet tds = new TableDataSet( connection, TurbineUserPeer.getTableName(), kd );
            StringBuffer where = new StringBuffer();
            where.append ( "loginid" );
            where.append ( "='" );
            where.append ( username );
            where.append ( "'" );
            tds.where ( where.toString() );
            TableDataSet tds2 = null;
            try
            {
                tds.fetchRecords(1);
                if ( tds.size() == 1 )
                {
                    Record rec = tds.getRecord(0);
                    
                    // check to make sure the user entered the right confirmation key
                    // if not, then send them to the ConfirmRegistration screen
                    String confirm_value = rec.getValue("CONFIRM_VALUE").asString();
                    if ( ! secretkey.equals ( confirm_value ) && ! confirm_value.equals ( CONFIRM_VALUE ) )
                    {
                        data.setMessage(Localization.getString("JLOGINUSER_KEYNOTVALID"));
                        data.setScreen("ConfirmRegistration");
                        return;
                    }
                    
                    // if the user is not confirmed
                    if ( ! confirm_value.equals ( CONFIRM_VALUE ) )
                    {
                        rec.setValue ( "CONFIRM_VALUE", CONFIRM_VALUE );
                        rec.save();
			
                        // Asign this user the role of authenticated_user.
                        // This feature was added at 26.01.2000
                        // by Bernie Hoeneisen, ETH Zurich, mailto:bhoeneis@ee.ethz.ch
                        String visitor_id = null;
                        String role_id = null;
			
                        visitor_id = rec.getValue("VISITORID").asString();
                        
                        // select role_id of authenticated_user from UserRole
                        kd = new KeyDef().addAttrib("ROLENAME");
                        tds2 =  new TableDataSet( connection, RolePeer.getTableName(), kd );
                        tds2.where ( "ROLENAME='authenticated_user'" );
                        tds2.fetchRecords(1);
                        if ( tds2.size() == 1 )
                        {
                            role_id = tds2.getRecord(0).getValue("ROLEID").asString();
                        }
                        else
                        {
                            throw new Exception(Localization
                                    .getString("JLOGINUSER_NOAUTHUSERROLE"));
                        }
			
                        // add  visitor_id, role_id to VisitorRole
                        Criteria crit = new Criteria();
                        crit.add ( VisitorRolePeer.getColumnName("VISITORID"), visitor_id );
                        crit.add ( VisitorRolePeer.getColumnName("ROLEID"), role_id );
                        try
                        {
                            VisitorRolePeer.doInsert(crit);
                        }
                        catch ( SQLException e )
                        {
                            // ignore. there is a possibility that this already exists.
                            // because we may be re-confirming a user after the user 
                            // edited their email address. in that case, this code 
                            // has already been executed and we are set.
                        }
                        // End: Asign this user the role of authenticated_user.
                    }
                    
                    String password = rec.getValue("PASSWORD_VALUE").asString();
                    data.getParameters().add ( "username", username );
                    data.getParameters().add ( "password", password );
                    data.setMessage (Localization.getString("JLOGINUSER_WELCOME"));
                }
                else
                {
                    StringBuffer msg = new StringBuffer();
                    msg.append (Localization.getString("JLOGINUSER_NAMENOTVALID"));
                    data.setMessage ( msg.toString() );
                    data.setScreen("NewAccount");
                    return;
                }
            }
            finally
            {
                if ( tds != null ) tds.close();
                if ( tds2 != null ) tds2.close();
                DBBroker.getInstance().releaseConnection(db);
            }
        }
        
        // check for valid username/password
        ActionLoader.getInstance().exec(data, "LoginUser");
        
        // check for being confirmed before allowing someone to finish logging in
        if ( data.getUser().hasLoggedIn() )
        {
            // get a connection to the db
            DBConnection db = DBBroker.getInstance().getConnection();
            Connection connection = db.getConnection();
            // execute the query
            StringBuffer sql = new StringBuffer();
            sql.append ("select confirm_value from Visitor where visitorid=" );
            sql.append ( data.getUser().getId() );
            sql.append (" and " );
            sql.append (" confirm_value='" );
            sql.append ( CONFIRM_VALUE );
            sql.append ( "'" );

            QueryDataSet qds = new QueryDataSet(connection, sql.toString() );
            try
            {
                qds.fetchRecords(1);
                if ( qds.size() == 0 )
                {
                    data.setMessage(Localization.getString("JLOGINUSER_CONFIRMFIRST"));
                    data.setScreen ("ConfirmRegistration");
                    data.getUser().setHasLoggedIn(new Boolean (false) );
                    return;
                }
            }
            finally
            {
                if ( qds != null ) qds.close();
                DBBroker.getInstance().releaseConnection(db);
            }
        }
        
        // we are all logged in. now we must update the previous values with the 
        // hidden fields on the page. the reason we do it here is because any variables 
        // that we originally associated with the user are lost because they are not transfered
        // to the new User object that is created to track the user. This is something that is 
        // part of turbine and i'm not sure if it should be changed or not for convenience.
        Integer question_id = (Integer) data.getParameters().getInteger("question_id", new Integer(-1));
        if ( question_id != null && question_id.intValue() != -1 )
        {
            data.getUser().setTemp("question_id", question_id);
        }
        Integer topic_id = (Integer) data.getParameters().getInteger("topic_id", new Integer(-1));
        if ( topic_id != null && topic_id.intValue() != -1 )
        {
            data.getUser().setTemp("topic_id", topic_id);
        }
        Integer answer_id = (Integer) data.getParameters().getInteger("answer_id", new Integer(-1));
        if ( answer_id != null && answer_id.intValue() != -1 )
        {
            data.getUser().setTemp("answer_id", answer_id);
        }
        Integer faq_id = (Integer) data.getParameters().getInteger("faq_id", new Integer(-1));
        if ( faq_id != null && faq_id.intValue() != -1 )
        {
            data.getUser().setTemp("faq_id", faq_id);
        }
        Integer project_id = (Integer) data.getParameters().getInteger("project_id", new Integer(-1));
        if ( project_id != null && project_id.intValue() != -1 )
        {
            data.getUser().setTemp("project_id", project_id);
        }
        if ( data.getUser().hasLoggedIn() )
        {
            data.getUser().setTemp("showedit", 
                new Boolean((boolean)data.getParameters().getBoolean("showedit", false)));
        }
        else
        {
            data.getUser().setTemp("showedit", new Boolean(false));
        }
    }
}