package org.apache.jyve.actions;

/*
 * Copyright (c) 1997-1999 The Java Apache Project.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. All advertising materials mentioning features or use of this
 *    software must display the following acknowledgment:
 *    "This product includes software developed by the Java Apache
 *    Project for use in the Apache JServ servlet engine project
 *    <http://java.apache.org/>."
 *
 * 4. The names "Apache JServ", "Apache JServ Servlet Engine", "Jyve",
 *    "Apache Jyve", "Jyve Project", "Apache Jyve Project" and
 *    "Java Apache Project" must not be used to endorse or promote products
 *    derived from this software without prior written permission.
 *
 * 5. Products derived from this software may not be called "Apache JServ"
 *    nor may "Apache" nor "Apache JServ" appear in their names without
 *    prior written permission of the Java Apache Project.
 *
 * 6. Redistributions of any form whatsoever must retain the following
 *    acknowledgment:
 *    "This product includes software developed by the Java Apache
 *    Project for use in the Apache JServ servlet engine project
 *    <http://java.apache.org/>."
 *
 * THIS SOFTWARE IS PROVIDED BY THE JAVA APACHE PROJECT "AS IS" AND ANY
 * EXPRESSED OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE JAVA APACHE PROJECT OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Java Apache Group. For more information
 * on the Java Apache Project and the Apache JServ Servlet Engine project,
 * please see <http://java.apache.org/>.
 *
 */

// JDK Stuff
import java.io.*;
import java.sql.*;
import java.util.Hashtable;

// Servlet Stuff
import javax.servlet.*;
import javax.servlet.http.*;

// External Stuff
import org.apache.jyve.util.*;
import org.apache.turbine.modules.*;
import org.apache.turbine.services.*;
import org.apache.turbine.services.localization.*;
import org.apache.turbine.util.*;
import org.apache.turbine.om.security.*;
import org.apache.turbine.util.db.*;
import org.apache.turbine.util.db.pool.*;
import com.workingdogs.village.*;
import org.apache.ecs.*;
import org.apache.ecs.html.*;

/**
 *  This class has been added 07.03.2000 by Bernie Hoeneisen, ETH Zurich
 *  <a href="mailto:bhoeneis@ee.ethz.ch">bhoeneis@ee.ethz.ch</a>
 *  It is used for releasing a project, faq, topic, question or answer in the database.
 *  <p>
 *  This class can only be used in conjunction with a class containing
 *  a method which implements getString() properly.
 *
 *  @author <a href="mailto:bhoeneis@ee.ethz.ch"> Bernie H&ouml;neisen</a>, ETH Zurich
 */

public abstract class Release extends Action
{
    /**
     *  This abstract method is implemented by the classes
     *  ReleaseProject, ..., ReleaseAnswer
     *  It fetches the different strings needed for the different tables.
     */
    abstract String getString(String key);
    
    final String tablename    = getString("tablename");
    final String Tablename    = getString("Tablename");
    final String TBLN         = getString("TBLN");
    final String tablename_id = getString("tablename_id");
    
    
    public void doPerform( RunData data ) throws Exception
    {
        // security check
        // failScreen = currentScreen
        JSecurityCheck secCheck = new JSecurityCheck(data,
            Localization.getString("RELEASE_" + TBLN + "_NORELEASEPERM"),
            data.getScreen() );
        if ( !secCheck.accessToActionRelease(tablename))
        {
            return;
        }
        
        // get project_id from URL  
        Integer id = new Integer(data.parameters.getInt(tablename_id, 0 ));
        if ( id == null || id.intValue() <= 0 )
        {
            // data.setScreen(???) // not required now, but might be required in future
            data.setMessage(Localization.getString("RELEASE_" + TBLN + "_NOVALID" + TBLN));
            return;
        }
        
        // get a connection to the db
        DBConnection db = DBBroker.getInstance().getConnection();
        Connection connection = db.getConnection();

        // execute the query
        KeyDef kd = new KeyDef().addAttrib(tablename_id);
        TableDataSet tds = new TableDataSet( connection, tablename, kd );
        tds.where ( tablename_id + "=" + id );
        try
        {
            tds.fetchRecords(1);
            if ( tds.size() == 1 )
            {
                Record rec = tds.getRecord(0);
                int uid = data.getUser().getId();
                if ( uid == -1 )
                    uid = 1;

                rec.setValue ( "released", "Y" );
                rec.setValue ( "released_by", uid );
                rec.setValue ( "released_date", new java.util.Date() );
                rec.save();
            }
        }
        finally
        {
            // close DB connection
            if ( tds != null ) tds.close();
            DBBroker.getInstance().releaseConnection(db);
        }

        // data.setScreen(???); // not required now, but might be required in future
        data.setMessage(Localization.getString("RELEASE_" + TBLN + "_" + TBLN + "RELEASED"));
    }    
}
