package org.apache.jyve.actions;

/*
 * Copyright (c) 1997-1999 The Java Apache Project.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. All advertising materials mentioning features or use of this
 *    software must display the following acknowledgment:
 *    "This product includes software developed by the Java Apache
 *    Project for use in the Apache JServ servlet engine project
 *    <http://java.apache.org/>."
 *
 * 4. The names "Apache JServ", "Apache JServ Servlet Engine", "Jyve",
 *    "Apache Jyve", "Jyve Project", "Apache Jyve Project" and
 *    "Java Apache Project" must not be used to endorse or promote products
 *    derived from this software without prior written permission.
 *
 * 5. Products derived from this software may not be called "Apache JServ"
 *    nor may "Apache" nor "Apache JServ" appear in their names without
 *    prior written permission of the Java Apache Project.
 *
 * 6. Redistributions of any form whatsoever must retain the following
 *    acknowledgment:
 *    "This product includes software developed by the Java Apache
 *    Project for use in the Apache JServ servlet engine project
 *    <http://java.apache.org/>."
 *
 * THIS SOFTWARE IS PROVIDED BY THE JAVA APACHE PROJECT "AS IS" AND ANY
 * EXPRESSED OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE JAVA APACHE PROJECT OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Java Apache Group. For more information
 * on the Java Apache Project and the Apache JServ Servlet Engine project,
 * please see <http://java.apache.org/>.
 *
 */

// JDK Stuff
import java.io.*;
import java.sql.*;
import java.util.Hashtable;

// Servlet Stuff
import javax.servlet.*;
import javax.servlet.http.*;

// External Stuff
import org.apache.jyve.util.*;
import org.apache.turbine.modules.*;
import org.apache.turbine.services.localization.Localization;
import org.apache.turbine.services.resources.TurbineResources;
import org.apache.turbine.util.*;
import org.apache.turbine.util.mail.*;
import org.apache.turbine.om.security.*;
import org.apache.turbine.om.security.peer.*;
import org.apache.turbine.om.user.*;
import org.apache.turbine.om.user.peer.*;
import org.apache.turbine.util.db.*;
import org.apache.turbine.util.db.pool.*;
import com.workingdogs.village.*;
import org.apache.ecs.*;
import org.apache.ecs.html.*;

/**
    This action will attempt to send a confirmation email to the user.
    This class is used in two places, the first one is for new users.
    The second is where a user is updating their information after they 
    have already created their account. If they are updating and they change 
    their email address, then we want to re-confirm it to prevent people from 
    screwing up their email address.
*/
public class SendConfirmationEmail extends Action
{
    public void doPerform( RunData data ) throws Exception
    {
        Integer visitorid = null;
        String username = null;
        if ( data.getUser().hasLoggedIn() )
        {
            visitorid = new Integer(data.getUser().getId());
            username = (String) data.getUser().getUserName();
        }
        else
        {
            visitorid = (Integer) data.getUser().getTemp("visitorid", new Integer(-1) );
            username = data.getParameters().getString("username", "");
        }

        String email = data.getParameters().getString("email", "");
        String firstname = data.getParameters().getString("firstname", "");
        String lastname = data.getParameters().getString("lastname", "");
        String nextscreen = data.getParameters().getString("nextscreen", "");

        RecordExtractor recEx = new RecordExtractor (data);
        String secretkey = recEx.getConfirmValue ( username ) ;
        
        DynamicURI url = new DynamicURI(data, "ConfirmRegistration")
            .addPathInfo("username", username )
            .addPathInfo("secretkey", secretkey)
            .addPathInfo("nextscreen", nextscreen );
        
        String email_body = Localization.getString("SENDCONFIRMATIONEMAIL_BODY1") +
        secretkey + "\n\n" + Localization.getString("SENDCONFIRMATIONEMAIL_BODY2") +
        "<" + url.toString() + ">";

        Criteria crit = new Criteria();
        crit.add ( Email.SENDER_EMAIL, TurbineResources
                                       .getString("jyve.confirm.email.from") );
        crit.add ( Email.SENDER_NAME, TurbineResources
                                       .getString("jyve.confirm.email.name") );
        crit.add ( Email.RECEIVER_EMAIL, email );
        crit.add ( Email.RECEIVER_NAME, firstname + " " + lastname );
        crit.add ( Email.EMAIL_SUBJECT, TurbineResources
                                            .getString("jyve.confirm.email.subject") );
        crit.add ( Email.EMAIL_BODY, email_body );

        try
        {
            SimpleEmail se = new SimpleEmail(crit);
            se.send();
            data.setMessage (Localization.getString("SENDCONFIRMATIONEMAIL_SENT"));
        }
        catch ( Exception e )
        {
            data.setMessage (Localization.getString("SENDCONFIRMATIONEMAIL_ERROR") + e.toString() );
        }
    }
}
