package org.apache.jyve.actions;

/*
 * Copyright (c) 1997-1999 The Java Apache Project.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. All advertising materials mentioning features or use of this
 *    software must display the following acknowledgment:
 *    "This product includes software developed by the Java Apache
 *    Project for use in the Apache JServ servlet engine project
 *    <http://java.apache.org/>."
 *
 * 4. The names "Apache JServ", "Apache JServ Servlet Engine", "Jyve",
 *    "Apache Jyve", "Jyve Project", "Apache Jyve Project" and
 *    "Java Apache Project" must not be used to endorse or promote products
 *    derived from this software without prior written permission.
 *
 * 5. Products derived from this software may not be called "Apache JServ"
 *    nor may "Apache" nor "Apache JServ" appear in their names without
 *    prior written permission of the Java Apache Project.
 *
 * 6. Redistributions of any form whatsoever must retain the following
 *    acknowledgment:
 *    "This product includes software developed by the Java Apache
 *    Project for use in the Apache JServ servlet engine project
 *    <http://java.apache.org/>."
 *
 * THIS SOFTWARE IS PROVIDED BY THE JAVA APACHE PROJECT "AS IS" AND ANY
 * EXPRESSED OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE JAVA APACHE PROJECT OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Java Apache Group. For more information
 * on the Java Apache Project and the Apache JServ Servlet Engine project,
 * please see <http://java.apache.org/>.
 *
 */

// JDK Stuff
import java.io.*;
import java.sql.*;
import java.util.Hashtable;

// Servlet Stuff
import javax.servlet.*;
import javax.servlet.http.*;

// External Stuff
import org.apache.turbine.modules.*;
import org.apache.turbine.services.*;
import org.apache.turbine.services.localization.*;
import org.apache.turbine.util.*;
import org.apache.turbine.om.security.*;
import org.apache.turbine.om.security.peer.*;
import org.apache.turbine.om.user.*;
import org.apache.turbine.om.user.peer.*;
import org.apache.turbine.util.db.*;
import org.apache.turbine.util.db.pool.*;
import com.workingdogs.village.*;
import org.apache.ecs.*;
import org.apache.ecs.html.*;

/**
    Updates an Account in the database. You must have been logged in in order
    to update the account.
*/
public class UpdateAccount extends Action
{
    public void doPerform( RunData data ) throws Exception
    {
        // check to make sure the user has logged in before accessing this screen
        if ( ! data.getUser().hasLoggedIn() )
        {
            data.setMessage(Localization.getString("UPDATEACCOUNT_NOTLOGGEDIN"));
            data.setScreen("MainMenu");
            removeButtons(data);
            return;
        }
        
        // check to see if the Cancel button was pressed.
        // if so, return to the screen we were previously on
        // defined by nextscreen in the EditAccount screen
        String submit = "submit1";
        String str = (String) data.getUser().getTemp ( submit, "asdfasdf" );
        if ( str != null && str
            .equalsIgnoreCase( data.getParameters().getString(submit, "")) )
        {
            removeButtons(data);
            return;
        }

        String password = data.getParameters().getString("password", "");
        String pass2 = data.getParameters().getString("password_confirm", "");        

        // if the fields are empty, then don't do anything to the passwords
        boolean changepass = false;
        if ( password.trim().length() > 0 && pass2.trim().length() > 0 )
        {
            changepass = true;
        }
        
        if ( changepass == true && ! password.equals ( pass2 ) )
        {
            data.setMessage(Localization.getString("UPDATEACCOUNT_PWNOTMATCH"));
            data.setScreen("EditAccount");
            removeButtons(data);
            return;
        }
        
        String firstname = data.getParameters().getString("firstname", "");
        // make sure the firstname exists
        if ( firstname.length() == 0 )
        {
            data.setMessage(Localization.getString("UPDATEACCOUNT_NOFIRSTNAME"));
            data.setScreen("EditAccount");
            removeButtons(data);
            return;
        }
        String lastname = data.getParameters().getString("lastname", "");
        // make sure the lastname exists
        if ( lastname.length() == 0 )
        {
            data.setMessage(Localization.getString("UPDATEACCOUNT_NOLASTNAME"));
            data.setScreen("EditAccount");
            removeButtons(data);
            return;
        }
        String email = data.getParameters().getString("email", "");
        // make sure the email exists
        if ( email.length() == 0 )
        {
            data.setMessage(Localization.getString("UPDATEACCOUNT_NOEMAIL"));
            data.setScreen("EditAccount");
            removeButtons(data);
            return;
        }
        
        // the Update button was clicked...now remove the buttons from memory
        // as we don't need them anymore.
        removeButtons(data);

        // get a connection to the db
        DBConnection db = DBBroker.getInstance().getConnection();
        Connection connection = db.getConnection();

        // execute the query
        KeyDef kd = new KeyDef().addAttrib(TurbineUserPeer.VISITOR_ID);
        TableDataSet tds = null;
        try
        {
            // find the user information
            tds = new TableDataSet(connection, TurbineUserPeer.getTableName(), kd );
            tds.where ( "VISITORID=" + data.getUser().getId() );
            tds.fetchRecords(1);
            if ( tds.size() == 1 )
            {
                Record rec = tds.getRecord(0);
                // update the record values
                if ( changepass )
                    rec.setValue("PASSWORD_VALUE", password );
                rec.setValue("FIRST_NAME", firstname );
                rec.setValue("LAST_NAME", lastname );

                // if the email addresses are different, then require the user to confirm again
                String currentEmail = (String) data.getUser().getPerm(TurbineUserPeer.EMAIL);
                if ( currentEmail == null || ! currentEmail.equalsIgnoreCase(email) )
                {
                    rec.setValue("EMAIL", email );
                    rec.setValue("CONFIRM_VALUE", GenerateUniqueId.getIdentifier() );
                    rec.save();
                    
                    ActionLoader.getInstance().exec(data, "SendConfirmationEmail");
                    // add in the username to the parameters because ConfirmRegistration needs it
                    data.getParameters().add("username", data.getUser().getUserName() );
                    data.setMessage(Localization.getString("UPDATEACCOUNT_NEWEMAILCONFIRM"));
                    data.setScreen("ConfirmRegistration");
                }
                else
                {       
                    rec.save();
                }
            
            }
            else
            {
                data.setMessage(Localization.getString("UPDATEACCOUNT_NOUSER"));
                data.setScreen("Login");
            }
        }
        finally
        {
            if ( tds != null ) tds.close();
            DBBroker.getInstance().releaseConnection(db);
        }
        
        // update currently logged in information that might have changed
        data.getUser().setPerm(TurbineUserPeer.FIRST_NAME, firstname);
        data.getUser().setPerm(TurbineUserPeer.LAST_NAME, lastname);
        data.getUser().setPerm(TurbineUserPeer.EMAIL, email);
        if ( changepass )
            data.getUser().setPerm(TurbineUserPeer.PASSWORD, password);

        data.setMessage (Localization.getString("UPDATEACCOUNT_DONE"));
    }
    
    /**
        Remove the button values from the temp storage.
    */
    private static void removeButtons (RunData data)
    {
        try
        {
            data.getUser().removeTemp("submit1");
            data.getUser().removeTemp("submit2");
        }
        catch (Exception e)
        {
        }
    }
}
