package org.apache.jyve.navigations;

/*
 * Copyright (c) 1997-1999 The Java Apache Project.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. All advertising materials mentioning features or use of this
 *    software must display the following acknowledgment:
 *    "This product includes software developed by the Java Apache
 *    Project for use in the Apache JServ servlet engine project
 *    <http://java.apache.org/>."
 *
 * 4. The names "Apache JServ", "Apache JServ Servlet Engine", "Jyve",
 *    "Apache Jyve", "Jyve Project", "Apache Jyve Project" and
 *    "Java Apache Project" must not be used to endorse or promote products
 *    derived from this software without prior written permission.
 *
 * 5. Products derived from this software may not be called "Apache JServ"
 *    nor may "Apache" nor "Apache JServ" appear in their names without
 *    prior written permission of the Java Apache Project.
 *
 * 6. Redistributions of any form whatsoever must retain the following
 *    acknowledgment:
 *    "This product includes software developed by the Java Apache
 *    Project for use in the Apache JServ servlet engine project
 *    <http://java.apache.org/>."
 *
 * THIS SOFTWARE IS PROVIDED BY THE JAVA APACHE PROJECT "AS IS" AND ANY
 * EXPRESSED OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE JAVA APACHE PROJECT OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Java Apache Group. For more information
 * on the Java Apache Project and the Apache JServ Servlet Engine project,
 * please see <http://java.apache.org/>.
 *
 */
 
// Java Core Classes
import java.io.*;
import java.sql.*;
import java.util.*;

// Java Servlet Classes
import javax.servlet.*;
import javax.servlet.http.*;

// External Stuff
import org.apache.jyve.util.*;
import org.apache.turbine.modules.*;
import org.apache.turbine.services.*;
import org.apache.turbine.services.localization.*;
import org.apache.turbine.util.*;
import org.apache.turbine.om.security.*;
import org.apache.turbine.util.db.*;
import org.apache.turbine.util.db.pool.*;
import com.workingdogs.village.*;
import org.apache.ecs.*;
import org.apache.ecs.html.*;

public class OptionsFooter extends Navigation
{
    public ConcreteElement doBuild( RunData data ) throws Exception
    {
        // show the options stuff
        ElementContainer ec = new ElementContainer();
        ec.addElement ( new HR().setSize(1).setNoShade(true) );
        ec.addElement ( new B(Localization.getString("OPTIONSFOOTER_OPTIONS")) );

        Boolean editCommands = (Boolean) data.getUser().getTemp("showedit", new Boolean(false));
        String editText = null;
        String editVal = null;
        if ( editCommands != null && editCommands.booleanValue() )
        {
          editText = Localization.getString("OPTIONSFOOTER_HIDEEDIT");
          editVal = "false";
        }
        else
        {
            editText = Localization.getString("OPTIONSFOOTER_SHOWEDIT");
            editVal = "true";
        }

        String loginText = null;
        String loginAction = "";
        String loginScreen = "";
        if ( data.getUser().hasLoggedIn() )
        {
            loginText = Localization.getString("OPTIONSFOOTER_LOGOUT");
            loginAction = "LogoutUser";
        }
        else
        {
            loginText = Localization.getString("OPTIONSFOOTER_LOGIN");
            loginScreen = "Login";
        }

        // show the menu of options
        Table table = new Table().setBorder(0).setCellPadding(5).setCellSpacing(0);
        TR tr = new TR();
        table.addElement( tr.addElement(new TD (
            new A().setHref(
            new DynamicURI(data, "MainMenu")
                .toString()
             ).addElement(Localization.getString("OPTIONSFOOTER_HOME"))
             ).setColSpan(2)));
        table.addElement( tr.addElement(new TD (
            new A().setHref(
            new DynamicURI(data, "SearchGlobal")
             .toString()
             ).addElement(Localization.getString("OPTIONSFOOTER_SEARCH"))
             ).setColSpan(2)));

        JSecurityCheck secCheck = new JSecurityCheck(data);
        if  ( ( secCheck.permissionToRelease("project") )
           || ( secCheck.permissionToRelease("faq") )
           || ( secCheck.permissionToRelease("topic") )
           || ( secCheck.permissionToRelease("question") )
           || ( secCheck.permissionToRelease("answer") ) ) 
        {
            table.addElement( tr.addElement(new TD (
                new A().setHref(
                new DynamicURI(data, "DisplayUnreleased")
                 .addPathInfo("nextscreen", data.getScreen() )
                 .toString()
                    ).addElement(Localization.getString("OPTIONSFOOTER_LISTUNRELEASED"))
                    ).setColSpan(2)));
        }
        
        table.addElement( tr.addElement(new TD (
            new A().setHref(
            new DynamicURI(data, data.getScreen(), "ShowEdit")
                .addPathInfo("showedit", editVal)
                .addPathInfo("nextscreen", data.getScreen() )
                .toString()
                ).addElement(editText)
                ).setColSpan(2)));
        table.addElement( tr.addElement(new TD (
            new A().setHref(
            new DynamicURI(data, loginScreen, loginAction)
                .addPathInfo("nextscreen", data.getScreen() )
                .toString()
                ).addElement(loginText)
                ).setColSpan(2)));
        if ( data.getUser().hasLoggedIn() )
        {
            table.addElement( tr.addElement(new TD (
                new A().setHref(
                new DynamicURI(data, "EditAccount")
                 .addPathInfo("nextscreen", data.getScreen() )
                 .toString()
                 ).addElement(Localization.getString("OPTIONSFOOTER_EDITACCOUNT"))
                 ).setColSpan(2)));
        }
        
        ec.addElement ( table );
        
        return ( ec );
    }
}
