package org.apache.jyve.navigations;

/*
 * Copyright (c) 1997-1999 The Java Apache Project.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. All advertising materials mentioning features or use of this
 *    software must display the following acknowledgment:
 *    "This product includes software developed by the Java Apache
 *    Project for use in the Apache JServ servlet engine project
 *    <http://java.apache.org/>."
 *
 * 4. The names "Apache JServ", "Apache JServ Servlet Engine", "Jyve",
 *    "Apache Jyve", "Jyve Project", "Apache Jyve Project" and
 *    "Java Apache Project" must not be used to endorse or promote products
 *    derived from this software without prior written permission.
 *
 * 5. Products derived from this software may not be called "Apache JServ"
 *    nor may "Apache" nor "Apache JServ" appear in their names without
 *    prior written permission of the Java Apache Project.
 *
 * 6. Redistributions of any form whatsoever must retain the following
 *    acknowledgment:
 *    "This product includes software developed by the Java Apache
 *    Project for use in the Apache JServ servlet engine project
 *    <http://java.apache.org/>."
 *
 * THIS SOFTWARE IS PROVIDED BY THE JAVA APACHE PROJECT "AS IS" AND ANY
 * EXPRESSED OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE JAVA APACHE PROJECT OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Java Apache Group. For more information
 * on the Java Apache Project and the Apache JServ Servlet Engine project,
 * please see <http://java.apache.org/>.
 *
 */
 
// Java Core Classes
import java.io.*;
import java.sql.*;
import java.util.*;

// Java Servlet Classes
import javax.servlet.*;
import javax.servlet.http.*;

// External Stuff
import org.apache.turbine.modules.*;
import org.apache.turbine.services.localization.Localization;
import org.apache.turbine.services.resources.TurbineResources;
import org.apache.turbine.util.*;
import org.apache.turbine.om.security.*;
import org.apache.turbine.util.db.*;
import org.apache.turbine.util.db.pool.*;
import com.workingdogs.village.*;
import org.apache.ecs.*;
import org.apache.ecs.html.*;

public class TopBar extends Navigation
{
    public ConcreteElement doBuild( RunData data ) throws Exception
    {
        // get colors from TurbineResources.properties
        String colorCellBgTitle = TurbineResources.
            getString("jyve.topbar.color.cell.bg.title");
        String colorCellTextTitle = TurbineResources.
            getString("jyve.topbar.htmlcolor.cell.text.title");
        String colorCellBgValue = TurbineResources.
            getString("jyve.topbar.color.cell.bg.value");
        String colorCellTextValue = TurbineResources.
            getString("jyve.topbar.htmlcolor.cell.text.value");

        // If valid HtmlColor then convert it to a Color String of hex values
        {
            String tmpColorText = HtmlColor.getColor(colorCellTextTitle);
            if (tmpColorText != null)
                colorCellTextTitle = tmpColorText;
            
            String tmpColorValue = HtmlColor.getColor(colorCellTextValue);
            if (tmpColorValue != null)
                colorCellTextValue = tmpColorValue;
        }
        
        Table table = new Table().setBorder(0).setCellPadding(5)
            .setCellSpacing(1);
        String project_value = (String)data.getUser().getTemp ( "project_value", null );
        if ( project_value == null )
            project_value = rebuildValue ( data, "project" );

        TR tr = new TR();
        if ( project_value != null )
        {
            tr.addElement ( new TD ().addElement(
                new Font().addElement(Localization.getString("TOPBAR_PROJECTSTITLE"))
                    .setColor(colorCellTextTitle))
                    .setBgColor(colorCellBgTitle));
            tr.addElement ( new TD ().addElement(
                new A().setHref(
                    new DynamicURI(data, "DisplayProjects")
                    .toString()
                ).addElement(new Font().addElement(project_value)
                    .setColor(colorCellTextValue).setSize(3))
            ).setBgColor(colorCellBgValue));
            String faq_value = (String)data.getUser().getTemp ( "faq_value", null );
            if ( faq_value == null )
                faq_value = rebuildValue ( data, "faq" );
            if ( faq_value != null )
            {
                tr.addElement ( new TD ().addElement(
                new Font().addElement(Localization.getString("TOPBAR_FAQTITLE"))
                    .setColor(colorCellTextTitle))
                    .setBgColor(colorCellBgTitle));
                tr.addElement ( new TD ().addElement(
                       new A().setHref(
                       new DynamicURI(data, "DisplayFaqs")
                          .toString()
                                ).addElement(new Font().addElement(faq_value)
                                    .setColor(colorCellTextValue).setSize(3))
                     ).setBgColor(colorCellBgValue));

                String topic_value = (String)data.getUser().getTemp ( "topic_value", null );
                if ( topic_value == null )
                    topic_value = rebuildValue ( data, "topic" );
                if ( topic_value != null )
                {
                    tr.addElement ( new TD ().addElement(
                    new Font().addElement(Localization.getString("TOPBAR_TOPICTITLE"))
                       .setColor(colorCellTextTitle))
                       .setBgColor(colorCellBgTitle));
                tr.addElement ( new TD ().addElement(
                          new A().setHref(
                          new DynamicURI(data, "DisplayTopics")
                             .toString()
                             ).addElement(new Font().addElement(topic_value)
                                .setColor(colorCellTextValue).setSize(3))
                    ).setBgColor(colorCellBgValue));
             }
          }
       }
       return table.addElement(tr);
    }

    /**
       This method is needed in case the values have been lost and
       the ID's still exist. In most cases, this will be because
       a user has been surfing the site as guest and then decided to
       log in. Login only keeps the ids and not the values.
    */
    private String rebuildValue ( RunData data, String table )
       throws Exception
    {
       // get a connection to the db
       DBConnection db = DBBroker.getInstance().getConnection();
       Connection connection = db.getConnection();

        StringBuffer sql = new StringBuffer();
        sql.append ( "select " );
        sql.append ( table );
        sql.append ( "_value from " );
        sql.append ( table );
        sql.append ( " where " );
        sql.append ( table );
        sql.append ( "_id=" );
        sql.append ( data.getUser().getTemp(table + "_id", new Integer(-1)) );
        QueryDataSet qds = new QueryDataSet( connection, sql.toString() );
        try
        {
            qds.fetchRecords(1);
            String result = null;
            if ( qds.size() > 0 )
            {
                result = qds.getRecord(0).getValue(1).asString();
                data.getUser().setTemp(table + "_value", result );
            }
            return result;
        }
        finally
        {
            if ( qds != null ) qds.close();
          DBBroker.getInstance().releaseConnection(db);
        }
    }
}
