package org.apache.jyve.screens;

/*
 * Copyright (c) 1997-1999 The Java Apache Project.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. All advertising materials mentioning features or use of this
 *    software must display the following acknowledgment:
 *    "This product includes software developed by the Java Apache
 *    Project for use in the Apache JServ servlet engine project
 *    <http://java.apache.org/>."
 *
 * 4. The names "Apache JServ", "Apache JServ Servlet Engine", "Jyve",
 *    "Apache Jyve", "Jyve Project", "Apache Jyve Project" and
 *    "Java Apache Project" must not be used to endorse or promote products
 *    derived from this software without prior written permission.
 *
 * 5. Products derived from this software may not be called "Apache JServ"
 *    nor may "Apache" nor "Apache JServ" appear in their names without
 *    prior written permission of the Java Apache Project.
 *
 * 6. Redistributions of any form whatsoever must retain the following
 *    acknowledgment:
 *    "This product includes software developed by the Java Apache
 *    Project for use in the Apache JServ servlet engine project
 *    <http://java.apache.org/>."
 *
 * THIS SOFTWARE IS PROVIDED BY THE JAVA APACHE PROJECT "AS IS" AND ANY
 * EXPRESSED OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE JAVA APACHE PROJECT OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Java Apache Group. For more information
 * on the Java Apache Project and the Apache JServ Servlet Engine project,
 * please see <http://java.apache.org/>.
 *
 */

// JDK Stuff
import java.util.*;

// External Stuff
import org.apache.turbine.modules.*;
import org.apache.turbine.services.*;
import org.apache.turbine.services.localization.*;
import org.apache.turbine.util.*;
import org.apache.turbine.om.security.*;
import org.apache.turbine.util.db.*;
import org.apache.turbine.util.db.pool.*;
import com.workingdogs.village.*;
import org.apache.ecs.*;
import org.apache.ecs.html.*;

public class ConfirmRegistration extends Screen
{
    public ConcreteElement doBuild( RunData data ) throws Exception
    {
        data.setTitle(Localization.getString("CONFIRMREGISTRATION_TITLE"));
        
        String nextscreen = data.parameters.getString ( "nextscreen", null );
        if ( nextscreen == null || nextscreen.equalsIgnoreCase("ConfirmRegistration"))
            nextscreen = "MainMenu";

        Form form = new Form ( new DynamicURI ( data, nextscreen, "JLoginUser", true ).toString()
            , Form.POST );

        String username = data.parameters.getString("username", null );
        if ( username == null )
        {
            data.setMessage(Localization.getString("CONFIRMREGISTRATION_NOUSERNAME"));
            return ScreenLoader.getInstance().eval ( data, "Login" );
        }
        form.addElement ( new Input ( Input.hidden, "username", username ) );

        // this is used to send people to the right place 
        // after having clicked Show Edit Commands
        // This has to be done with hidden fields because the guest user is wiped out
        // when they log in.
        form.addElement ( new Input ( Input.hidden, "nextscreen", nextscreen ));
        
        
        Integer question_id = (Integer) data.getUser().getTemp("question_id", 
            data.parameters.getInteger("question_id", -1 ) );
        if ( question_id != null && question_id.intValue() != -1 )
        {
            form.addElement ( new Input ( Input.hidden, "question_id", question_id ) );
        }
        Integer topic_id = (Integer) data.getUser().getTemp("topic_id", 
            data.parameters.getInteger("topic_id", -1 ));
        if ( topic_id != null && topic_id.intValue() != -1 )
        {
            form.addElement ( new Input ( Input.hidden, "topic_id", topic_id ) );
        }
        Integer answer_id = (Integer) data.getUser().getTemp("answer_id", 
            data.parameters.getInteger("answer_id", -1 ));
        if ( answer_id != null && answer_id.intValue() != -1 )
        {
            form.addElement ( new Input ( Input.hidden, "answer_id", answer_id ) );
        }
        Integer faq_id = (Integer) data.getUser().getTemp("faq_id", 
            data.parameters.getInteger("faq_id", -1 ));
        if ( faq_id != null && faq_id.intValue() != -1 )
        {
            form.addElement ( new Input ( Input.hidden, "faq_id", faq_id ) );
        }
        Integer project_id = (Integer) data.getUser().getTemp("project_id", 
            data.parameters.getInteger("project_id", -1 ));
        if ( project_id != null && project_id.intValue() != -1 )
        {
            form.addElement ( new Input ( Input.hidden, "project_id", project_id ) );
        }        
        Boolean showEdit = (Boolean)data.parameters.getBool("showedit");
        form.addElement ( new Input ( Input.hidden, "showedit", showEdit.toString() ) );

        // display a message, so the user knows he gets the secret key by email
        form.addElement (Localization.getString("CONFIRMREGISTRATION_MESSAGE"));
        form.addElement ( new P() );

        Table table = new Table().setCellSpacing(0).setCellPadding(0).setBorder(0);

        table.addElement ( new TR()
             .addElement ( new TD().addElement (Localization.getString("CONFIRMREGISTRATION_SECRETKEYTITLE"))
             .addElement ( new TD().addElement ( new Input(Input.TEXT, "secretkey", data.parameters.getString("secretkey", "")))
                 .setAlign(AlignType.right))));

        String buta = "submit1";
        String butb = "submit2";
        String but1 = Localization.getString("CONFIRMREGISTRATION_CANCEL");
        String but2 = Localization.getString("CONFIRMREGISTRATION_CONFIRM");

        ElementContainer ec = new ElementContainer();
        ec.addElement ( new Input ( Input.submit, buta, but1 ) );
        ec.addElement ( new Input ( Input.submit, butb, but2 ) );
        
        table.addElement ( new TR()
             .addElement ( new TD().addElement ( "&nbsp;" )
                .setColSpan(2)));
        table.addElement ( new TR()
             .addElement ( new TD().addElement ( ec )
                .setColSpan(2).setAlign(AlignType.right)));

        data.getUser().setTemp ( buta, but1 );
        data.getUser().setTemp ( butb, but2 );

        form.addElement ( table );
        return form;
    }
}