package org.apache.jyve.screens;

/*
 * Copyright (c) 1997-1999 The Java Apache Project.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. All advertising materials mentioning features or use of this
 *    software must display the following acknowledgment:
 *    "This product includes software developed by the Java Apache
 *    Project for use in the Apache JServ servlet engine project
 *    <http://java.apache.org/>."
 *
 * 4. The names "Apache JServ", "Apache JServ Servlet Engine", "Jyve",
 *    "Apache Jyve", "Jyve Project", "Apache Jyve Project" and
 *    "Java Apache Project" must not be used to endorse or promote products
 *    derived from this software without prior written permission.
 *
 * 5. Products derived from this software may not be called "Apache JServ"
 *    nor may "Apache" nor "Apache JServ" appear in their names without
 *    prior written permission of the Java Apache Project.
 *
 * 6. Redistributions of any form whatsoever must retain the following
 *    acknowledgment:
 *    "This product includes software developed by the Java Apache
 *    Project for use in the Apache JServ servlet engine project
 *    <http://java.apache.org/>."
 *
 * THIS SOFTWARE IS PROVIDED BY THE JAVA APACHE PROJECT "AS IS" AND ANY
 * EXPRESSED OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE JAVA APACHE PROJECT OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Java Apache Group. For more information
 * on the Java Apache Project and the Apache JServ Servlet Engine project,
 * please see <http://java.apache.org/>.
 *
 */

// JDK Stuff
import java.sql.*;
import java.util.*;

// External Stuff
import org.apache.jyve.util.*;
import org.apache.turbine.modules.*;
import org.apache.turbine.services.localization.Localization;
import org.apache.turbine.services.resources.TurbineResources;
import org.apache.turbine.util.*;
import org.apache.turbine.om.security.*;
import org.apache.turbine.util.db.*;
import org.apache.turbine.util.db.pool.*;
import com.workingdogs.village.*;
import org.apache.ecs.*;
import org.apache.ecs.html.*;

public class DisplayFaqs extends Screen
{
    public ConcreteElement doBuild( RunData data ) throws Exception
    {
        data.setTitle(Localization.getString("DISPLAYFAQS_TITLE"));

        Boolean showEdit = (Boolean)data.getUser().getTemp("showedit", new Boolean(false));
        if ( showEdit == null )
            showEdit = new Boolean(false);
        
        JSecurityCheck secCheck = new JSecurityCheck(data);
        boolean showReleaseButton=secCheck.permissionToRelease("faq");
        boolean showUnreleased = ( secCheck.permissionToRelease("faq") )
                              || ( secCheck.permissionToSeeUnreleased("faq") );
        int visitorId = data.getUser().getId();
        
        Integer project_id = (Integer) data.getUser().getTemp("project_id", 
            data.getParameters().getInteger("project_id", -1 ) );
        if ( project_id == null || project_id.intValue() == -1 )
        {
            data.setMessage(Localization.getString("DISPLAYFAQS_NOVALIDPRJ"));
            return ScreenLoader.getInstance().eval ( data, "MainMenu" );
        }
        // reset future screens so that TopNavBar renders properly
        data.getUser().removeTemp ( "topic_id" );
        data.getUser().removeTemp ( "topic_value" );
        data.getUser().removeTemp ( "faq_id" );
        data.getUser().removeTemp ( "faq_value" );

        ElementContainer ec = new ElementContainer();
        // show the top bar
        ec.addElement ( new P() );
        ec.addElement (
            NavigationLoader.getInstance().eval ( data, "TopBar" ) );
        ec.addElement ( new P() );

        ec.addElement ( new Font().addElement(Localization.getString("DISPLAYFAQS_CHOOSEFAQMSG"))
            .setSize(4) );
        
        StringBuffer sql = new StringBuffer();
        sql.append ( "select" );
        sql.append ( " faq.faq_id, faq.faq_value, faq.released" );
        sql.append ( " from" );
        sql.append ( " project, faq" );
        sql.append ( " where" );
        sql.append ( " project.project_id = faq.project_id" );
        sql.append ( " and" );
        sql.append ( " faq.project_id=" );
        sql.append ( project_id );        
        sql.append ( " and" );
        sql.append ( " faq.deleted='N'");

        if (!showUnreleased)
        {
            // select if the faq is released or it was created by the current visitor
            sql.append ( "AND ( faq.released='Y' OR faq.visitorid=");
            sql.append ( visitorId );
            sql.append ( ")");
        }
        
        sql.append ( " order by" );
        sql.append ( " faq.display_order" );
        // Order alphabetical, if same order number
        sql.append ( ",faq.faq_value" );
    
        // get a connection to the db
        DBConnection db = DBBroker.getInstance().getConnection();
        Connection connection = db.getConnection();

        // execute the query
        QueryDataSet qds = new QueryDataSet( connection, sql.toString() );
        int size = 0;
        String colorRowUnreleased = TurbineResources.
            getString("jyve.display.color.row.unreleased");
        String colorTableBackground = TurbineResources.
            getString("jyve.display.color.table.background");

        Table faq_table = new Table().setBorder(0).setCellSpacing(0)
            .setCellPadding(0).setWidth("70%");
        try
        {
            qds.fetchRecords();
            size = qds.size();
            int counter = 1;
            for ( int i = 0; i<size; i++ )
            {
                int faq_id = qds.getRecord(i).getValue("faq_id").asInt();
                String faq_value = qds.getRecord(i).getValue("faq_value").asString();
                boolean recordReleased;
                if ( qds.getRecord(i).getValue("released").asString().equalsIgnoreCase("Y") )
                    recordReleased = true;
                else
                    recordReleased = false;                

                TR tr = new TR();

                // set special bg color for the rows if unreleased entry
                if ( !recordReleased )
                    tr.setBgColor(colorRowUnreleased);
                
                TD td = new TD();
                td.setWidth("75%");                
                td.addElement ( counter + ". " );
                td.addElement (
                    new A().setHref(
                    new DynamicURI(data, "DisplayTopics", "SetAll")
                        .addPathInfo("project_id", project_id)
                        .addPathInfo("faq_id", faq_id)
                        .toString()
                        ).addElement(faq_value)
                     );
                tr.addElement(td);

                if ( showEdit.booleanValue() )
                {
                    tr.addElement ( new TD()
                      .addElement (
                        new A().setHref(
                        new DynamicURI(data, "EditFaq", "SetAll")
                            .addPathInfo("project_id", project_id)
                            .addPathInfo("faq_id", faq_id)
                            .toString()
                            ).addElement(Localization.getString("DISPLAYFAQS_MODIFY"))
                         ));

                    if ((showReleaseButton) && (!recordReleased) )
                    {
                        tr.addElement ( new TD()
                            .addElement (
                                new A().setHref(
                                new DynamicURI(data, "DisplayFaqs", "ReleaseFaq")
                                    .addPathInfo("project_id", project_id)
                                    .addPathInfo("faq_id", faq_id)
                                    .toString()
                                    ).addElement(Localization.getString("DISPLAYFAQS_RELEASE"))
                        ));
                    }
                }

                faq_table.addElement (tr);
                counter++;
            }
        }
        finally
        {
            if ( qds != null ) qds.close();
            DBBroker.getInstance().releaseConnection(db);
        }
        
        Table table = new Table().setBorder(1)
            .setBgColor(colorTableBackground).setWidth("100%")
            .setCellPadding(25).setCellSpacing(1);
    
        if ( size > 0 )
        {
            ec.addElement(table.addElement(new TR().addElement ( new TD(faq_table) )));
        }
        else
        {
            ec.addElement(table.addElement(new TR().addElement ( new TD(
                Localization.getString("DISPLAYFAQS_NOFAQ")
            ))));
        }
        if ( showEdit.booleanValue() )
        {
            ec.addElement ( new P() );
            ec.addElement ( 
                new A().setHref(
                new DynamicURI(data, "NewFaq", "SetAll")
                    .addPathInfo("project_id", project_id)
                    .toString()
                    ).addElement(Localization.getString("DISPLAYFAQS_ADDNEWFAQ"))
            );
        }

        return ec;
    }
}
