package org.apache.jyve.screens;

/*
 * Copyright (c) 1997-1999 The Java Apache Project.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. All advertising materials mentioning features or use of this
 *    software must display the following acknowledgment:
 *    "This product includes software developed by the Java Apache
 *    Project for use in the Apache JServ servlet engine project
 *    <http://java.apache.org/>."
 *
 * 4. The names "Apache JServ", "Apache JServ Servlet Engine", "Jyve",
 *    "Apache Jyve", "Jyve Project", "Apache Jyve Project" and
 *    "Java Apache Project" must not be used to endorse or promote products
 *    derived from this software without prior written permission.
 *
 * 5. Products derived from this software may not be called "Apache JServ"
 *    nor may "Apache" nor "Apache JServ" appear in their names without
 *    prior written permission of the Java Apache Project.
 *
 * 6. Redistributions of any form whatsoever must retain the following
 *    acknowledgment:
 *    "This product includes software developed by the Java Apache
 *    Project for use in the Apache JServ servlet engine project
 *    <http://java.apache.org/>."
 *
 * THIS SOFTWARE IS PROVIDED BY THE JAVA APACHE PROJECT "AS IS" AND ANY
 * EXPRESSED OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE JAVA APACHE PROJECT OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Java Apache Group. For more information
 * on the Java Apache Project and the Apache JServ Servlet Engine project,
 * please see <http://java.apache.org/>.
 *
 */

// JDK Stuff
import java.util.*;

// External Stuff
import org.apache.jyve.util.*;
import org.apache.turbine.modules.*;
import org.apache.turbine.services.localization.Localization;
import org.apache.turbine.services.resources.TurbineResources;
import org.apache.turbine.util.*;
import org.apache.turbine.om.security.*;
import org.apache.turbine.util.db.*;
import org.apache.turbine.util.db.pool.*;
import com.workingdogs.village.*;
import org.apache.ecs.*;
import org.apache.ecs.html.*;

public class DisplayOneTopic extends Screen
{
    public ConcreteElement doBuild( RunData data ) throws Exception
    {
        data.setTitle(Localization.getString("DISPLAYONETOPIC_TITLE"));

        Boolean showEdit = (Boolean)data.getUser().getTemp("showedit", new Boolean(false));
        if ( showEdit == null )
            showEdit = new Boolean(false);
            
        JSecurityCheck secCheck = new JSecurityCheck(data);
        boolean showReleaseButton=secCheck.permissionToRelease("topic");
        boolean showUnreleased = ( secCheck.permissionToRelease("topic") )
                              || ( secCheck.permissionToSeeUnreleased("topic") );
        int visitorId = data.getUser().getId();

        Integer project_id = (Integer) data.getUser().getTemp("project_id", 
            data.getParameters().getInteger("project_id", -1 ) );
        if ( project_id == null || project_id.intValue() == -1 )
        {
            data.setMessage(Localization.getString("DISPLAYONETOPIC_NOVALIDPRJ"));
            return ScreenLoader.getInstance().eval ( data, "MainMenu" );
        }
        Integer faq_id = (Integer) data.getUser().getTemp("faq_id", 
            data.getParameters().getInteger("faq_id", -1 ) );
        if ( faq_id == null || faq_id.intValue() == -1 )
        {
            data.setMessage(Localization.getString("DISPLAYONETOPIC_NOVALIDFAQTOPIC"));
            return ScreenLoader.getInstance().eval ( data, "DisplayFaqs" );
        }
        Integer topic_id = (Integer) data.getUser().getTemp("topic_id", 
            data.getParameters().getInteger("topic_id", -1 ) );
        if ( topic_id == null || topic_id.intValue() == -1 )
        {
            data.setMessage(Localization.getString("DISPLAYONETOPIC_NOVALIDTOPIC"));
            return ScreenLoader.getInstance().eval ( data, "DisplayTopics" );
        }

        RecordExtractor recEx = new RecordExtractor (data);
        boolean topicReleased = recEx.isReleased("topic", topic_id);
                
        ElementContainer ec = new ElementContainer();
        // show the top bar
        ec.addElement ( new P() );
        ec.addElement (
            NavigationLoader.getInstance().eval ( data, "TopBar" ) );
        ec.addElement ( new P() );

            ec.addElement ( new Font().addElement(Localization.getString("DISPLAYONETOPIC_CHOOSEQUESTIONFROMTOPIC"))
                    .setSize(4) );
        
        StringBuffer sql = new StringBuffer();
        sql.append ( "select" );
        sql.append ( " topic.topic_id, topic.topic_value, topic.released" );
        sql.append ( " from" );
        sql.append ( " topic, faq" );
        sql.append ( " where" );
        sql.append ( " faq.faq_id=topic.faq_id" );
        sql.append ( " and" );
        sql.append ( " topic.topic_id=" );
        sql.append ( topic_id );
        sql.append ( " and" );
        sql.append ( " topic.faq_id=" );
        sql.append ( faq_id );
        sql.append ( " and" );
        sql.append ( " topic.deleted='N'" );

        if (!showUnreleased)
        {
            // select if the topic is released or the topic was added by the current visitor
            sql.append ( "AND ( topic.released='Y' OR topic.visitorid=");
            sql.append ( visitorId );
            sql.append ( ")");
        }

        sql.append ( " and" );
        sql.append ( " faq.deleted='N'" );
        sql.append ( " order by" );
        sql.append ( " topic.display_order" );
        // Order alphabetical, if same order number
        sql.append ( ",topic.topic_value" );

        String colorRowUnreleased = TurbineResources.
            getString("jyve.display.color.row.unreleased");
        String colorTableBackground = TurbineResources.
            getString("jyve.display.color.table.background");

        Table table = new Table().setBorder(1)
            .setBgColor(colorTableBackground).setWidth("100%")
            .setCellPadding(25).setCellSpacing(1);
        TD td = new TD();

        if ( !topicReleased )
            td.setBgColor(colorRowUnreleased);
            
        DisplayTopics.buildTopicTree ( data, sql, td );
        
        ec.addElement(table.addElement(new TR().addElement(td)));

        if ( showEdit.booleanValue() )
        {
            ec.addElement ( new P() );
            ec.addElement ( 
                new A().setHref(
                new DynamicURI(data, "NewQuestion", "SetAll")
                    .addPathInfo("project_id", project_id)
                    .addPathInfo("faq_id", faq_id)
                    .addPathInfo("topic_id", topic_id)
                    .toString()
                    ).addElement(Localization.getString("DISPLAYONETOPIC_ADDNEWQUESTION"))
                    );
            ec.addElement ( " " );
            ec.addElement(
                 new A().setHref(
                      new DynamicURI(data, "EditTopic")
                          .addPathInfo("project_id", project_id)
                          .addPathInfo("faq_id", faq_id)
                          .addPathInfo("topic_id", topic_id)
                          .toString()
                          ).addElement(Localization.getString("DISPLAYONETOPIC_MODIFYTOPIC"))
                     );

            if ((showReleaseButton) && (!topicReleased) )
            {
                ec.addElement ( " " );
                ec.addElement (
                     new A().setHref(
                          new DynamicURI(data, "DisplayOneTopic", "ReleaseTopic")
                              .addPathInfo("project_id", project_id)
                              .addPathInfo("faq_id", faq_id)
                              .addPathInfo("topic_id", topic_id)
                              .toString()
                              ).addElement(Localization.getString("DISPLAYONETOPIC_RELEASETOPIC"))
                         );
            }    
            
        }
        return ec;
    }
}
