package org.apache.jyve.screens;

/*
 * Copyright (c) 1997-1999 The Java Apache Project.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. All advertising materials mentioning features or use of this
 *    software must display the following acknowledgment:
 *    "This product includes software developed by the Java Apache
 *    Project for use in the Apache JServ servlet engine project
 *    <http://java.apache.org/>."
 *
 * 4. The names "Apache JServ", "Apache JServ Servlet Engine", "Jyve",
 *    "Apache Jyve", "Jyve Project", "Apache Jyve Project" and
 *    "Java Apache Project" must not be used to endorse or promote products
 *    derived from this software without prior written permission.
 *
 * 5. Products derived from this software may not be called "Apache JServ"
 *    nor may "Apache" nor "Apache JServ" appear in their names without
 *    prior written permission of the Java Apache Project.
 *
 * 6. Redistributions of any form whatsoever must retain the following
 *    acknowledgment:
 *    "This product includes software developed by the Java Apache
 *    Project for use in the Apache JServ servlet engine project
 *    <http://java.apache.org/>."
 *
 * THIS SOFTWARE IS PROVIDED BY THE JAVA APACHE PROJECT "AS IS" AND ANY
 * EXPRESSED OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE JAVA APACHE PROJECT OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Java Apache Group. For more information
 * on the Java Apache Project and the Apache JServ Servlet Engine project,
 * please see <http://java.apache.org/>.
 *
 */

// JDK Stuff
import java.sql.*;

// External Stuff
import org.apache.jyve.util.*;
import org.apache.turbine.modules.*;
import org.apache.turbine.services.localization.Localization;
import org.apache.turbine.services.resources.TurbineResources;
import org.apache.turbine.util.*;
import org.apache.turbine.om.security.*;
import org.apache.turbine.util.db.*;
import org.apache.turbine.util.db.pool.*;
import com.workingdogs.village.*;
import org.apache.ecs.*;
import org.apache.ecs.html.*;

public class DisplayProjects extends Screen
{
    public ConcreteElement doBuild( RunData data ) throws Exception
    {
        data.setTitle(Localization.getString("DISPLAYPROJECTS_TITLE"));

        Boolean showEdit = (Boolean)data.getUser().getTemp("showedit", new Boolean(false));
        if ( showEdit == null )
            showEdit = new Boolean(false);
        
        JSecurityCheck secCheck = new JSecurityCheck(data);
        boolean showReleaseButton=secCheck.permissionToRelease("project");
        boolean showUnreleased = ( secCheck.permissionToRelease("project") )
                              || ( secCheck.permissionToSeeUnreleased("project") );
        int visitorId = data.getUser().getId();

        ElementContainer ec = new ElementContainer();
        ec.addElement ( new Font().addElement(Localization.getString("DISPLAYPROJECTS_CHOOSEPRJMSG")).setSize(4) );

        StringBuffer sql = new StringBuffer();
        sql.append ( "select" );
        sql.append ( " project.project_id, project.project_value, project.released" );
        sql.append ( " from" );
        sql.append ( " project" );
        sql.append ( " where" );
        sql.append ( " project.deleted='N'");

        if (!showUnreleased)
        {
            // select if the project is released or it was created by the current visitor
            sql.append ( "AND ( project.released='Y' OR project.visitorid=");
            sql.append ( visitorId );
            sql.append ( ")");
        }
        
        sql.append ( " order by" );
        sql.append ( " project.display_order" );
        // Order alphabetical, if same order number
        sql.append ( ",project.project_value" );

        // get a connection to the db
        DBConnection db = DBBroker.getInstance().getConnection();
        Connection connection = db.getConnection();

        // execute the query
        QueryDataSet qds = new QueryDataSet( connection, sql.toString() );
        int size = 0;
        String colorRowUnreleased = TurbineResources.
            getString("jyve.display.color.row.unreleased");
        String colorTableBackground = TurbineResources.
            getString("jyve.display.color.table.background");
        
        Table project_table = new Table().setBorder(0).setCellSpacing(0)
            .setCellPadding(0).setWidth("70%");
        try
        {
            qds.fetchRecords();
            size = qds.size();
            int counter = 1;
            for ( int i = 0; i<size; i++ )
            {
                int project_id = qds.getRecord(i).getValue("project_id").asInt();
                String project_value = qds.getRecord(i).getValue("project_value").asString();
                boolean recordReleased;
                if ( qds.getRecord(i).getValue("released").asString().equalsIgnoreCase("Y") )
                    recordReleased = true;
                else
                    recordReleased = false;
                
                TR tr = new TR();

                // set special bg color for the rows if unreleased entry
                if ( !recordReleased )
                    tr.setBgColor(colorRowUnreleased);
                
                TD td = new TD();
                td.setWidth("75%");
                td.addElement ( counter + ". " );
                td.addElement (
                    new A().setHref(
                    new DynamicURI(data, "DisplayFaqs", "SetAll")
                        .addPathInfo("project_id", project_id)
                        .toString()
                    ).addElement(project_value)
                );
                tr.addElement(td);

                if ( showEdit.booleanValue() )
                {
                    tr.addElement ( new TD()
                        .addElement (
                            new A().setHref(
                            new DynamicURI(data, "EditProject", "SetAll")
                               .addPathInfo("project_id", project_id)
                               .toString()
                        ).addElement(Localization.getString("DISPLAYPROJECTS_MODIFY"))
                    ));

                    if ((showReleaseButton) && (!recordReleased) )
                    {
                        tr.addElement ( new TD()
                            .addElement (
                                new A().setHref(
                                new DynamicURI(data, "DisplayProjects", "ReleaseProject")
                                    .addPathInfo("project_id", project_id)
                                    .toString()
                                    ).addElement(Localization.getString("DISPLAYPROJECTS_RELEASE"))
                        ));
                    }
                }
            
                project_table.addElement (tr);
                counter++;
            }
        }
        finally
        {
            if (qds!=null) qds.close();
            DBBroker.getInstance().releaseConnection(db);

        }

        Table table = new Table().setBorder(1)
            .setBgColor(colorTableBackground).setWidth("100%")
            .setCellPadding(25).setCellSpacing(1);
        if ( size > 0 )
        {
            ec.addElement(table.addElement(new TR().addElement ( new TD(project_table) )));
        }
        else
        {
            ec.addElement(table.addElement(new TR().addElement ( new TD(
            Localization.getString("DISPLAYPROJECTS_NOPRJ")
            ) )));
        }

        if ( showEdit.booleanValue() )
        {
            ec.addElement ( new P() );
            ec.addElement (
                new A().setHref(
                new DynamicURI(data, "NewProject")
                .toString()
                ).addElement(Localization.getString("DISPLAYPROJECTS_ADDNEWPRJ"))
            );
        }
        return ec;
    }
}
