package org.apache.jyve.screens;

/*
 * Copyright (c) 1997-1999 The Java Apache Project.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. All advertising materials mentioning features or use of this
 *    software must display the following acknowledgment:
 *    "This product includes software developed by the Java Apache
 *    Project for use in the Apache JServ servlet engine project
 *    <http://java.apache.org/>."
 *
 * 4. The names "Apache JServ", "Apache JServ Servlet Engine", "Jyve",
 *    "Apache Jyve", "Jyve Project", "Apache Jyve Project" and
 *    "Java Apache Project" must not be used to endorse or promote products
 *    derived from this software without prior written permission.
 *
 * 5. Products derived from this software may not be called "Apache JServ"
 *    nor may "Apache" nor "Apache JServ" appear in their names without
 *    prior written permission of the Java Apache Project.
 *
 * 6. Redistributions of any form whatsoever must retain the following
 *    acknowledgment:
 *    "This product includes software developed by the Java Apache
 *    Project for use in the Apache JServ servlet engine project
 *    <http://java.apache.org/>."
 *
 * THIS SOFTWARE IS PROVIDED BY THE JAVA APACHE PROJECT "AS IS" AND ANY
 * EXPRESSED OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE JAVA APACHE PROJECT OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Java Apache Group. For more information
 * on the Java Apache Project and the Apache JServ Servlet Engine project,
 * please see <http://java.apache.org/>.
 *
 */

// JDK Stuff
import java.sql.*;

// External Stuff
import org.apache.jyve.util.*;
import org.apache.turbine.modules.*;
import org.apache.turbine.services.localization.Localization;
import org.apache.turbine.services.resources.TurbineResources;
import org.apache.turbine.util.*;
import org.apache.turbine.om.security.*;
import org.apache.turbine.om.security.peer.*;
import org.apache.turbine.om.user.*;
import org.apache.turbine.om.user.peer.*;
import org.apache.turbine.util.db.*;
import org.apache.turbine.util.db.pool.*;
import com.workingdogs.village.*;
import org.apache.ecs.*;
import org.apache.ecs.html.*;
import org.apache.ecs.filter.*;

public class DisplayQuestionAnswer extends Screen
{
    public ConcreteElement doBuild( RunData data ) throws Exception
    {
        data.setTitle(Localization.getString("DISPLAYQUESTIONANSWER_TITLE"));

        Boolean showEdit = (Boolean)data.getUser().getTemp("showedit", new Boolean(false));
        if ( showEdit == null )
            showEdit = new Boolean(false);

        // get values from TurbineResources.properties
        boolean showCreator;
        if (TurbineResources.getString("jyve.displayqa.showcreator").equalsIgnoreCase("yes"))
            showCreator=true;
        else
            showCreator=false;

        boolean showLastModifiedDate;
        if (TurbineResources.getString("jyve.displayqa.showlastmodifieddate").equalsIgnoreCase("yes"))
            showLastModifiedDate=true;
        else
            showLastModifiedDate=false;

        JSecurityCheck secCheck = new JSecurityCheck(data);
        boolean showReleaseQuestionButton = secCheck.permissionToRelease("question");
        boolean showUnreleasedQuestion =  ( secCheck.permissionToRelease("question") )
                                 || ( secCheck.permissionToSeeUnreleased("question") );
        boolean showReleaseAnswerButton = secCheck.permissionToRelease("answer");
        boolean showUnreleasedAnswer =  ( secCheck.permissionToRelease("answer") )
                               || ( secCheck.permissionToSeeUnreleased("answer") );
        int visitorId = data.getUser().getId();

        Integer topic_id = (Integer) data.getUser().getTemp("topic_id", 
            data.getParameters().getInteger("topic_id", -1 ) );
        if ( topic_id == null || topic_id.intValue() == -1 )
        {
            data.setMessage(Localization.getString("DISPLAYQUESTIONANSWER_NOVALIDTOPIC"));
            return ScreenLoader.getInstance().eval ( data, "DisplayTopics" );
        }
        Integer question_id = (Integer) data.getUser().getTemp("question_id", 
            data.getParameters().getInteger("question_id", -1 ) );
        if ( question_id == null || question_id.intValue() == -1 )
        {
            data.setMessage(Localization.getString("DISPLAYQUESTIONANSWER_NOVALIDQUESTION"));
            return ScreenLoader.getInstance().eval ( data, "DisplayTopics" );
        }

        ElementContainer ec = new ElementContainer();
        // show the top bar
        ec.addElement ( new P() );
        ec.addElement (
            NavigationLoader.getInstance().eval ( data, "TopBar" ) );
        ec.addElement ( new P() );


        if ( TurbineResources.getString("jyve.displayqa.showprevnextnav", "yes").equalsIgnoreCase("yes") )
        {
            Element prevNext = NavigationLoader.getInstance().eval ( data, "PrevNextQuestion" );
            if ( prevNext != null )
                ec.addElement ( prevNext );
        }

        // get a connection to the db
        DBConnection db = DBBroker.getInstance().getConnection();
        Connection connection = db.getConnection();

        // execute the query
        StringBuffer sql = new StringBuffer();
        sql.append ( "select " );
        sql.append ( " question.question_value" );
        sql.append ( ", question.released" );
        sql.append ( ", question.MODIFIED_DATE AS qmd" );
        sql.append ( ", Visitor.VISITORID, Visitor.LOGINID" );
        sql.append ( " from" );
        sql.append ( " question, Visitor" );
        sql.append ( " where" );
        sql.append ( " question.question_id=" );
        sql.append ( question_id );
        sql.append ( " and" );
        sql.append ( " question.visitorid=Visitor.visitorid" );
        sql.append ( " and" );
        sql.append ( " question.deleted='N'" );

        if (!showUnreleasedQuestion)
        {
            // select if the question is released or it was created by the current visitor
            sql.append ( "AND ( question.released='Y' OR question.visitorid=");
            sql.append ( visitorId );
            sql.append ( ")");
        }

        // The following seems to be overspecified; thus I commented it out
        // 26.04.2000; Bernie
        //
        // sql.append ( " order by" );
        // sql.append ( " question.display_order" );

        QueryDataSet qds = new QueryDataSet( connection, sql.toString() );
        try
        {
            qds.fetchRecords(1);
            int size = qds.size();
            
            if ( size > 0 )
            {
                String question_value = qds.getRecord(0).getValue("question_value").asString();
//                int question_id = qds.getRecord(0).getValue("question_id").asInt();
                String t_loginid = qds.getRecord(0).getValue("loginid").asString();
                String t_visitorid = qds.getRecord(0).getValue("visitorid").asString();
                java.util.Date t_modified_date = qds.getRecord(0).getValue("qmd").asUtilDate();

                boolean questionReleased;
                if ( qds.getRecord(0).getValue("released").asString().equalsIgnoreCase("Y") )
                    questionReleased=true;
                else
                    questionReleased=false;
                
                String colorRowReleasedQuestion = TurbineResources.
                    getString("jyve.display.color.row.title");
                String colorRowUnreleasedQuestion = TurbineResources.
                    getString("jyve.display.color.row.unreleased.question");
                String colorRowUnreleasedAnswer = TurbineResources.
                    getString("jyve.display.color.row.unreleased");
                String colorTableBackground = TurbineResources.
                    getString("jyve.display.color.table.background");
                
                Table table = new Table().setBorder(0).setCellSpacing(1)
                    .setCellPadding(5).setWidth("100%");
                table.setBgColor(colorTableBackground);

                TR tr1 = new TR();

                // set bg color for the question row depending on
                // whether the question is released or not
                if ( questionReleased )
                    tr1.setBgColor(colorRowReleasedQuestion);
                else
                    tr1.setBgColor(colorRowUnreleasedQuestion);
                
                tr1
                  .addElement ( new TD(
                      new Font().addElement(question_value)
                          .setSize(4).setColor(HtmlColor.white)
                          .setFace("helvetica,arial"))
                      );

                if (showCreator) 
                {
                    tr1.addElement ( new TD(
                        new Font().addElement(
                            new A().setHref(
                                new DynamicURI(data, "DisplayUser")
                                    .addPathInfo("visitorid", t_visitorid)
                                    .toString()
                                    ).addElement(t_loginid)
                                ).setSize(1).setColor(HtmlColor.white)
                            .setFace("helvetica,arial"))
                        .setAlign(AlignType.middle).setWidth("10%")
                        );
                }

                if (showLastModifiedDate)
                {
                    tr1.addElement ( new TD(
                        new Font().addElement(
                            "Last Mod: " + t_modified_date.toString()
                            ).setSize(1).setColor(HtmlColor.white)
                            .setFace("helvetica,arial")
                            ).setAlign(AlignType.middle).setWidth("10%")
                        );
                }

                if ( showEdit.booleanValue() )
                {
                    tr1.addElement (new TD(
                        new Font().addElement(
                            new A().setHref(
                            new DynamicURI(data, "EditQuestion", "SetAll")
                                .addPathInfo("question_id", question_id)
                                .toString()
                                ).addElement(Localization.getString("DISPLAYQUESTIONANSWER_MODIFY"))
                          ).setSize(1)).setAlign(AlignType.middle)
                        );
                    if ((showReleaseQuestionButton) && (!questionReleased))
                    {       
                        tr1.addElement (new TD(
                        new Font().addElement(
                            new A().setHref(
                            new DynamicURI(data, "DisplayQuestionAnswer", "ReleaseQuestion")
                                .addPathInfo("question_id", question_id)
                                .toString()
                                ).addElement(Localization.getString("DISPLAYQUESTIONANSWER_RELEASE"))
                               ).setSize(1)).setAlign(AlignType.middle)
                            );
                    }
                }
                
                table.addElement(tr1);
                
                // get all the answers
                
                sql = new StringBuffer();
                sql.append ( "select distinct" );
                sql.append ( " answer.answer_id, answer.answer_value, answer.savetype" );
                sql.append ( ", answer.released, answer.display_order" );
                sql.append ( ", answer.MODIFIED_DATE AS amd" );
                sql.append ( ", Visitor.VISITORID, Visitor.LOGINID" );
                sql.append ( " from" );
                sql.append ( " answer, Visitor" );
                sql.append ( " where" );
                sql.append ( " answer.question_id=" );
                sql.append ( question_id );
                sql.append ( " and" );
                sql.append ( " answer.deleted='N'" );

                if (!showUnreleasedAnswer)
                {
                    // select if the answer is released or it was created by the current visitor
                    sql.append ( "AND ( answer.released='Y' OR answer.visitorid=");
                    sql.append ( visitorId );
                    sql.append ( ")");
                }
                
                sql.append ( " and" );
                sql.append ( " answer.visitorid=Visitor.visitorid" );
                sql.append ( " order by" );
                sql.append ( " answer.display_order" );

                // Maybe someone wants to use also here
                // ordering alphabetical, if same order number;
                // in this case just uncomment the next line.
                // sql.append ( ",answer.answer_value" );

                qds = new QueryDataSet( connection, sql.toString() );
                qds.fetchRecords();
                size = qds.size();

                boolean answerReleased;

                if ( size > 0 )
                {
                    for ( int i =0;i<size;i++ )
                    {
                        if ( qds.getRecord(i).getValue("released").asString().equalsIgnoreCase("Y") )
                            answerReleased=true;
                        else
                            answerReleased=false;
                
                        String savetype = qds.getRecord(i).getValue("savetype").asString();
                        if ( savetype == null )
                            savetype = "H";
                        ElementContainer answer_value = new ElementContainer();
                        if ( savetype.equals("P") )
                        {
                            Filter filter = new CharacterFilter();
                            filter.addAttribute("<","&lt;");
                            filter.addAttribute(">","&gt;");
                            answer_value.addElement( new PRE().addElement (
                                filter.process ( qds.getRecord(i).getValue("answer_value").asString() )
                                ));
                        }
                        else
                        {
                            answer_value.addElement( 
                                qds.getRecord(i).getValue("answer_value").asString() );
                        }
                        int answer_id = qds.getRecord(i).getValue("answer_id").asInt();
                        t_loginid = qds.getRecord(i).getValue("loginid").asString();
                        t_visitorid = qds.getRecord(i).getValue("visitorid").asString();
                        t_modified_date = qds.getRecord(i).getValue("amd").asUtilDate();
                        TR tr2 = new TR();
                        
                        // set special bg color for the rows if unreleased answer
                        if ( ! answerReleased )
                            tr2.setBgColor(colorRowUnreleasedAnswer);
                        
                        tr2
                          .addElement ( new TD(
                              new Font().addElement(answer_value)
                                  ));

                        if (showCreator) 
                        {
                            tr2.addElement ( new TD(
                                new Font().addElement(
                                    new A().setHref(
                                        new DynamicURI(data, "DisplayUser")
                                            .addPathInfo("visitorid", t_visitorid)
                                            .toString()
                                        ).addElement(t_loginid)
                                    ).setSize(1)
                                ).setAlign(AlignType.middle)
                            );
                        }

                        if (showLastModifiedDate)
                        {
                            tr2.addElement ( new TD(
                                new Font().addElement(Localization.getString("DISPLAYQUESTIONANSWER_LASTMOD")
                                        + t_modified_date.toString())
                                    .setSize(1)
                                ).setAlign(AlignType.middle)
                            );
                        }

                        if ( showEdit.booleanValue() )
                        {
                            tr2.addElement (new TD(
                                new Font().addElement(
                                    new A().setHref(
                                        new DynamicURI(data, "EditAnswer", "SetAll")
                                            .addPathInfo("answer_id", answer_id)
                                            .addPathInfo("question_id", question_id)
                                            .toString()
                                    ).addElement(Localization.getString("DISPLAYQUESTIONANSWER_MODIFY"))
                                ).setSize(1)).setAlign(AlignType.middle)
                            );
                            if ( (showReleaseAnswerButton) && (!answerReleased) )
                            {
                                tr2.addElement (new TD(
                                    new Font().addElement(
                                        new A().setHref(
                                            new DynamicURI(data, "DisplayQuestionAnswer", "ReleaseAnswer")
                                                .addPathInfo("answer_id", answer_id)
                                                .addPathInfo("question_id", question_id)
                                                .toString()
                                                ).addElement(Localization.getString("DISPLAYQUESTIONANSWER_RELEASE"))
                                    ).setSize(1)).setAlign(AlignType.middle)
                                );
                                }
                            
                        }
                        table.addElement ( tr2 );
                    }
                }
                ec.addElement ( table );
                if ( size == 0 )
                    {
                        ec.addElement (Localization.getString("DISPLAYQUESTIONANSWER_NOANSWER"));
                    }
            }
            else
                {
                    ec.addElement ( Localization.getString("DISPLAYQUESTIONANSWER_NOQUESTION"));
                }
            if ( showEdit.booleanValue() )
                {
                    ec.addElement ( new P() );
                    ec.addElement (
                         new A().setHref(
                              new DynamicURI(data, "NewAnswer", "SetAll")
                                  .addPathInfo("question_id", question_id)
                                  .toString()
                                  ).addElement(Localization.getString("DISPLAYQUESTIONANSWER_ADDANSWER"))
                             );
                }
        }
        finally
        {
            if ( qds != null ) qds.close();
            DBBroker.getInstance().releaseConnection(db);

        }
        return ec;
    }
}
