package org.apache.jyve.screens;

/*
 * Copyright (c) 1997-1999 The Java Apache Project.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. All advertising materials mentioning features or use of this
 *    software must display the following acknowledgment:
 *    "This product includes software developed by the Java Apache
 *    Project for use in the Apache JServ servlet engine project
 *    <http://java.apache.org/>."
 *
 * 4. The names "Apache JServ", "Apache JServ Servlet Engine", "Jyve",
 *    "Apache Jyve", "Jyve Project", "Apache Jyve Project" and
 *    "Java Apache Project" must not be used to endorse or promote products
 *    derived from this software without prior written permission.
 *
 * 5. Products derived from this software may not be called "Apache JServ"
 *    nor may "Apache" nor "Apache JServ" appear in their names without
 *    prior written permission of the Java Apache Project.
 *
 * 6. Redistributions of any form whatsoever must retain the following
 *    acknowledgment:
 *    "This product includes software developed by the Java Apache
 *    Project for use in the Apache JServ servlet engine project
 *    <http://java.apache.org/>."
 *
 * THIS SOFTWARE IS PROVIDED BY THE JAVA APACHE PROJECT "AS IS" AND ANY
 * EXPRESSED OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE JAVA APACHE PROJECT OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Java Apache Group. For more information
 * on the Java Apache Project and the Apache JServ Servlet Engine project,
 * please see <http://java.apache.org/>.
 *
 */

// JDK Stuff
import java.sql.*;

// External Stuff
import org.apache.jyve.util.*;
import org.apache.turbine.modules.*;
import org.apache.turbine.services.localization.Localization;
import org.apache.turbine.services.resources.TurbineResources;
import org.apache.turbine.util.*;
import org.apache.turbine.om.security.*;
import org.apache.turbine.util.db.*;
import org.apache.turbine.util.db.pool.*;
import com.workingdogs.village.*;
import org.apache.ecs.*;
import org.apache.ecs.html.*;

public class DisplayTopics extends Screen
{
    public ConcreteElement doBuild( RunData data ) throws Exception
    {
        data.setTitle(Localization.getString("DISPLAYTOPICS_TITLE"));

        Boolean showEdit = (Boolean)data.getUser().getTemp("showedit", new Boolean(false));
        if ( showEdit == null )
            showEdit = new Boolean(false);
            
        JSecurityCheck secCheck = new JSecurityCheck(data);
        // boolean showReleaseButton=secCheck.permissionToRelease("topic");
        boolean showUnreleased = ( secCheck.permissionToRelease("topic") )
                              || ( secCheck.permissionToSeeUnreleased("topic") );
        int visitorId = data.getUser().getId();

        Integer project_id = (Integer) data.getUser().getTemp("project_id", 
            data.getParameters().getInteger("project_id", -1 ) );
        if ( project_id == null || project_id.intValue() == -1 )
        {
            data.setMessage(Localization.getString("DISPLAYTOPICS_NOVALIDPRJ"));
            return ScreenLoader.getInstance().eval ( data, "MainMenu" );
        }
        Integer faq_id = (Integer) data.getUser().getTemp("faq_id", 
            data.getParameters().getInteger("faq_id", -1 ) );
        if ( faq_id == null || faq_id.intValue() == -1 )
        {
            data.setMessage(Localization.getString("DISPLAYTOPICS_NOVALIDFAQTOPIC"));
            return ScreenLoader.getInstance().eval ( data, "DisplayFaqs" );
        }
        // reset future screens so that TopNavBar renders properly
        data.getUser().removeTemp ( "topic_id" );
        data.getUser().removeTemp ( "topic_value" );

        ElementContainer ec = new ElementContainer();
        // show the top bar
        ec.addElement ( new P() );
        ec.addElement (
            NavigationLoader.getInstance().eval ( data, "TopBar" ) );
        ec.addElement ( new P() );

        ec.addElement ( new Font().addElement(Localization.getString("DISPLAYTOPICS_CHOOSETORQ")).setSize(4) );
        
        StringBuffer sql = new StringBuffer();
        sql.append ( "select" );
        sql.append ( " topic.topic_id, topic.topic_value, topic.released" );
        sql.append ( " from" );
        sql.append ( " topic, faq" );
        sql.append ( " where" );
        sql.append ( " faq.faq_id=topic.faq_id" );
        sql.append ( " and" );
        sql.append ( " topic.faq_id=" );
        sql.append ( faq_id );
        sql.append ( " and" );
        sql.append ( " topic.deleted='N'" );

        if (!showUnreleased)
        {
            // select if the topic is released or the topic was added by the current visitor
            sql.append ( "AND ( topic.released='Y' OR topic.visitorid=");
            sql.append ( visitorId );
            sql.append ( ")");
        }
        
        sql.append ( " and" );
        sql.append ( " faq.deleted='N'" );
        sql.append ( " order by" );
        sql.append ( " topic.display_order" );
        // Order alphabetical, if same order number
        sql.append ( ",topic.topic_value" );
        
        String colorTableBackground = TurbineResources.
            getString("jyve.display.color.table.background");

        Table table = new Table().setBorder(1)
            .setBgColor(colorTableBackground).setWidth("100%")
            .setCellPadding(25).setCellSpacing(1);
        TD td = new TD();
        buildTopicTree ( data, sql, td );
        
        ec.addElement(table.addElement(new TR().addElement(td)));
        
        if ( showEdit.booleanValue() )
        {
            ec.addElement ( new P() );
            ec.addElement ( 
                new A().setHref(
                new DynamicURI(data, "NewTopic", "SetAll")
                    .addPathInfo("project_id", project_id)
                    .addPathInfo("faq_id", faq_id)
                    .toString()
                    ).addElement(Localization.getString("DISPLAYTOPICS_ADDNEWTOPIC"))
            );
        }
        return ec;
    }

    static void buildTopicTree( RunData data, StringBuffer sql, TD ec )
        throws Exception
    {
        
        JSecurityCheck secCheck = new JSecurityCheck(data);
        boolean showUnreleasedQuestion =
            ( secCheck.permissionToRelease("question") )
            || ( secCheck.permissionToSeeUnreleased("question") );
        boolean showUnreleasedAnswer =
            ( secCheck.permissionToRelease("answer") )
            || ( secCheck.permissionToSeeUnreleased("answer") );
        int visitorId = data.getUser().getId();
        
        // get a connection to the db
        DBConnection db = DBBroker.getInstance().getConnection();
        Connection connection = db.getConnection();

        // execute the query
        QueryDataSet qds = new QueryDataSet( connection, sql.toString() );
        OL topic_ol = new OL();
        try
        {
            qds.fetchRecords();
            int size = qds.size();
            if ( size == 0 )
            {
                ec.addElement ( new P() );
                ec.addElement (Localization.getString("DISPLAYTOPICS_NOTOPICS"));
                return;
            }

            int[] topic_ids = new int[size];
            String[] topic_values = new String[size];
            boolean[] topic_released = new boolean[size];
            
            for (int i=0;i<size;i++)
            {
                topic_ids[i] = qds.getRecord(i).getValue("topic_id").asInt();
                topic_values[i] = qds.getRecord(i).getValue("topic_value").asString();
                if ( qds.getRecord(i).getValue("released").asString().equalsIgnoreCase("Y") )
                    topic_released[i]=true;
                else
                    topic_released[i]=false;
                
            }
            
            sql = new StringBuffer();
            sql.append ( "select" );
            sql.append ( " question.question_id, question.question_value, question.topic_id, question.released" );

            if ( !showUnreleasedAnswer )
            {
                // count if an answer is not deleted and
                // if it is released or it was created by the current visitor
                sql.append ( " , sum(if((answer.deleted='N' AND (answer.released='Y' OR answer.visitorid=");
                sql.append ( visitorId );
                sql.append ( ")),1,0)) as answer_count");
            }
            else
                sql.append ( " , sum(if(answer.deleted='N',1,0)) as answer_count");
            
            sql.append ( " from" );
            sql.append ( " question" );
            sql.append ( " left join answer on" );
            sql.append ( " question.question_id = answer.question_id" );
            sql.append ( " where" );
            sql.append ( " question.topic_id in (" );

            boolean comma = false;
            for (int i=0;i<size;i++)
            {
                if ( ! comma )
                {
                    sql.append ( topic_ids[i] );
                    comma = true;
                }
                else
                {
                    sql.append ( "," );
                    sql.append ( topic_ids[i] );
                }
            }
            sql.append ( " )" );

            sql.append ( " and" );
            sql.append ( " question.deleted='N'" );

            if (!showUnreleasedQuestion)
            {
                // select if the question is released or it was created by the current visitor
                sql.append ( "AND ( question.released='Y' OR question.visitorid=");
                sql.append ( visitorId );
                sql.append ( ")");
            }

            sql.append ( " group by" );
            sql.append ( " question.question_id, question.question_value, question.topic_id" );
            sql.append ( " order by" );
            sql.append ( " question.topic_id, question.display_order" );
            // Order alphabetical, if same order number
            sql.append ( ",question.question_value" );

            qds = new QueryDataSet( connection, sql.toString() );
            qds.fetchRecords();
            size = qds.size();
            
            // re-get some values
            Integer project_id = (Integer) data.getUser().getTemp("project_id", 
                data.getParameters().getInteger("project_id", -1 ) );
            Integer faq_id = (Integer) data.getUser().getTemp("faq_id", 
                data.getParameters().getInteger("faq_id", -1 ) );
                    
            OL question_ol = null;
            for ( int i = 0; i<topic_ids.length; i++ )
            {
                topic_ol.addElement ( new LI().addElement ( 
                new A().setHref(
                new DynamicURI(data, "DisplayOneTopic", "SetAll")
                    .addPathInfo("project_id", project_id)
                    .addPathInfo("faq_id", faq_id)
                    .addPathInfo("topic_id", topic_ids[i])
                    .toString()
                    ).addElement(topic_values[i])
                 ) );

                if ( !topic_released[i] )
                    topic_ol.addElement(new I().addElement(" (Not released yet!)"));
                // Localization missing!!!!!
                
                question_ol = new OL();

                for ( int j = 0; j<size; j++ )
                {
                    int d_question_id = qds.getRecord(j).getValue("question_id").asInt();   
                    int d_topic_id = qds.getRecord(j).getValue("topic_id").asInt();
                    String d_question_value = qds.getRecord(j).getValue("question_value").asString();
                    int d_answer_count = qds.getRecord(j).getValue("answer_count").asInt();

                    if ( d_topic_id == topic_ids[i] )
                    {
                        question_ol.addElement ( new LI().addElement ( 
                            new A().setHref(
                            new DynamicURI(data, "DisplayQuestionAnswer", "SetAll")
                                .addPathInfo("project_id", project_id)
                                .addPathInfo("faq_id", faq_id)
                                .addPathInfo("topic_id", topic_ids[i])
                                .addPathInfo("question_id", d_question_id)
                                .toString()
                                ).addElement(d_question_value)
                            ).addElement(" ("+d_answer_count+")") );

                        if ( !qds.getRecord(j).getValue("released").asString().equalsIgnoreCase("Y") )
                            question_ol.addElement(new I().addElement(" (Not released yet!)"));
                        // Localization missing!!!!!
                        
                        topic_ol.addElement ( question_ol );
                    }
                }
            }
            ec.addElement (topic_ol);
        }
        finally
        {
            qds.close();
            DBBroker.getInstance().releaseConnection(db);

        }
    }
}
