package org.apache.jyve.screens;

/*
 * Copyright (c) 1997-1999 The Java Apache Project.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. All advertising materials mentioning features or use of this
 *    software must display the following acknowledgment:
 *    "This product includes software developed by the Java Apache
 *    Project for use in the Apache JServ servlet engine project
 *    <http://java.apache.org/>."
 *
 * 4. The names "Apache JServ", "Apache JServ Servlet Engine", "Jyve",
 *    "Apache Jyve", "Jyve Project", "Apache Jyve Project" and
 *    "Java Apache Project" must not be used to endorse or promote products
 *    derived from this software without prior written permission.
 *
 * 5. Products derived from this software may not be called "Apache JServ"
 *    nor may "Apache" nor "Apache JServ" appear in their names without
 *    prior written permission of the Java Apache Project.
 *
 * 6. Redistributions of any form whatsoever must retain the following
 *    acknowledgment:
 *    "This product includes software developed by the Java Apache
 *    Project for use in the Apache JServ servlet engine project
 *    <http://java.apache.org/>."
 *
 * THIS SOFTWARE IS PROVIDED BY THE JAVA APACHE PROJECT "AS IS" AND ANY
 * EXPRESSED OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE JAVA APACHE PROJECT OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Java Apache Group. For more information
 * on the Java Apache Project and the Apache JServ Servlet Engine project,
 * please see <http://java.apache.org/>.
 *
 */

// JDK Stuff
import java.sql.*;

// External Stuff
import org.apache.turbine.modules.*;
import org.apache.turbine.services.*;
import org.apache.turbine.services.localization.*;
import org.apache.turbine.util.*;
import org.apache.turbine.om.security.*;
import org.apache.turbine.om.security.peer.*;
import org.apache.turbine.om.user.*;
import org.apache.turbine.om.user.peer.*;
import org.apache.turbine.util.db.*;
import org.apache.turbine.util.db.pool.*;
import com.workingdogs.village.*;
import org.apache.ecs.*;
import org.apache.ecs.html.*;

public class DisplayUser extends Screen
{
    public ConcreteElement doBuild( RunData data ) throws Exception
    {
        data.setTitle(Localization.getString("DISPLAYUSER_TITLE"));
        
        Integer visitorid = (Integer) data.parameters.getInteger("visitorid", -1 );
        if ( visitorid == null || visitorid.intValue() == -1 )
        {
            return ScreenLoader.getInstance().eval ( data, "DisplayQuestionAnswer" );
        }
        boolean hasEmail = true;

        ElementContainer ec = new ElementContainer();
        // show the top bar
        ec.addElement ( new P() );
        ec.addElement (
            NavigationLoader.getInstance().eval ( data, "TopBar" ) );
        ec.addElement ( new P() );

        User tu = new TurbineUser().retrieveFromStorage(visitorid);
        String first_name = (String) tu.getPerm (TurbineUserPeer.FIRST_NAME);
        String last_name = (String) tu.getPerm (TurbineUserPeer.LAST_NAME);
        String email = (String) tu.getPerm (TurbineUserPeer.EMAIL);
        java.util.Date lastlogin = (java.util.Date) tu.getPerm (TurbineUserPeer.getColumnName("LASTLOGIN"));
        
        StringBuffer sb = new StringBuffer();
        if ( first_name != null && first_name.length() > 0
            && last_name != null && last_name.length() > 0 )
        {
            sb.append ( first_name );
            sb.append ( " " );
            sb.append ( last_name );
        }
        if ( email == null )
        {
            email = "";
            hasEmail = false;
        }
        ec.addElement ( new Font().addElement(Localization.getString("DISPLAYUSER_INFOMSG"))
            .setSize(4) );
        ec.addElement ( new P() );
        
        Table table1 = new Table().setBorder(0).setCellSpacing(0).setCellPadding(0);
        
        table1.addElement (  new TR()
            .addElement ( new TD(new B().addElement(Localization.getString("DISPLAYUSER_NAMEMSG")) ) )
            .addElement ( new TD( sb.toString() ) ) );
        table1.addElement (  new TR()
            .addElement ( new TD(new B().addElement(Localization.getString("DISPLAYUSER_LOGINMSG")) ) )
              .addElement ( new TD( lastlogin.toString() ) ) );

//        table1.addElement (  new TR()
//            .addElement ( new TD("Email: " ) )
//            .addElement ( new TD( email ) ) );
        ec.addElement ( table1 );

        Form form = null;
        if ( hasEmail )
        {
            ec.addElement ( new P() );
            ec.addElement ( new HR().setSize(1).setNoShade(true) );
            
            form = new Form ( new DynamicURI ( data, "DisplayQuestionAnswer", "SendUserEmail", true ).toString()
                , Form.POST );
            form.addElement ( new Input ( Input.hidden, "visitorid", visitorid ) );
            form.addElement ( new Input ( Input.hidden, "receiver_name", sb.toString() ) );
    
            // build some nice text
            first_name = (String) data.getUser().getPerm (TurbineUserPeer.FIRST_NAME);
            last_name = (String) data.getUser().getPerm (TurbineUserPeer.LAST_NAME);
            email = (String) data.getUser().getPerm (TurbineUserPeer.EMAIL);
    
            sb = new StringBuffer();
            if ( first_name != null && first_name.length() > 0
                && last_name != null && last_name.length() > 0 )
            {
                sb.append ( first_name );
                sb.append ( " " );
                sb.append ( last_name );
            }
            if ( email == null )
                email = "";
    
            Table table2 = new Table().setBorder(0).setCellSpacing(0).setCellPadding(0);
            
            String email_subject = data.parameters.getString ( "email_subject", "" );
            String email_body = data.parameters.getString ( "email_body", "" );
    
            table2.addElement (  new TR()
                .addElement ( new TD (
                     new Font().addElement(Localization.getString("DISPLAYUSER_WARNING") )
                        .setSize(4).setColor(HtmlColor.RED) 
                    ).setColSpan(2) ) );
            table2.addElement (  new TR()
                .addElement ( new TD(
                         new Font().addElement(Localization.getString("DISPLAYUSER_SENDMAILMSG")).setSize(4)
                    ).setColSpan(2) ) );
            table2.addElement (  new TR()
                .addElement ( new TD("&nbsp;").setColSpan(2) ) );
            table2.addElement (  new TR()
                .addElement ( new TD(Localization.getString("DISPLAYUSER_USERNAMEMSG")) )
                .addElement ( new TD( new Input ( Input.text, "sender_name", sb.toString() ) ) ) );
            table2.addElement (  new TR()
                .addElement ( new TD(Localization.getString("DISPLAYUSER_EMAILMSG")) )
                .addElement ( new TD( new Input ( Input.text, "sender_email", email ) ) ) );
            table2.addElement (  new TR()
                .addElement ( new TD(Localization.getString("DISPLAYUSER_SUBJECTMSG")) )
                .addElement ( new TD( new Input ( Input.text, "email_subject", email_subject ) ) ) );
            table2.addElement (  new TR()
                .addElement ( new TD(Localization.getString("DISPLAYUSER_BODYMSG")) )
                .addElement ( new TD( new TextArea("email_body", 5, 60)
                    .addElement (email_body)
                    .setWrap(TextArea.VIRTUAL) ) ) );
    
            table2.addElement ( new TR().addElement(
                new TD("&nbsp;").setColSpan(2).setAlign(AlignType.right)) );
    
            String buta = "submit1";
            String butc = "submit3";
            String but1 = Localization.getString("DISPLAYUSER_CANCEL");
            String but3 = Localization.getString("DISPLAYUSER_SENDMAIL");
    
            table2.addElement ( new TR().addElement(
                new TD().addElement ( new Input ( Input.submit, buta, but1 ) )
                    .addElement ( new Input ( Input.submit, butc, but3 ) )
                    .setAlign(AlignType.right).setColSpan(2) ));
    
            data.getUser().setTemp ( buta, but1 );
            data.getUser().setTemp ( butc, but3 );
    
            form.addElement ( table2 );
            ec.addElement ( form );
        }
        return ec;
    }
}
