package org.apache.jyve.screens;

/*
 * Copyright (c) 1997-1999 The Java Apache Project.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. All advertising materials mentioning features or use of this
 *    software must display the following acknowledgment:
 *    "This product includes software developed by the Java Apache
 *    Project for use in the Apache JServ servlet engine project
 *    <http://java.apache.org/>."
 *
 * 4. The names "Apache JServ", "Apache JServ Servlet Engine", "Jyve",
 *    "Apache Jyve", "Jyve Project", "Apache Jyve Project" and
 *    "Java Apache Project" must not be used to endorse or promote products
 *    derived from this software without prior written permission.
 *
 * 5. Products derived from this software may not be called "Apache JServ"
 *    nor may "Apache" nor "Apache JServ" appear in their names without
 *    prior written permission of the Java Apache Project.
 *
 * 6. Redistributions of any form whatsoever must retain the following
 *    acknowledgment:
 *    "This product includes software developed by the Java Apache
 *    Project for use in the Apache JServ servlet engine project
 *    <http://java.apache.org/>."
 *
 * THIS SOFTWARE IS PROVIDED BY THE JAVA APACHE PROJECT "AS IS" AND ANY
 * EXPRESSED OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE JAVA APACHE PROJECT OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Java Apache Group. For more information
 * on the Java Apache Project and the Apache JServ Servlet Engine project,
 * please see <http://java.apache.org/>.
 *
 */

// JDK Stuff
import java.sql.*;
import java.util.*;

// External Stuff
import org.apache.turbine.modules.*;
import org.apache.turbine.services.localization.Localization;
import org.apache.turbine.services.resources.TurbineResources;
import org.apache.turbine.util.*;
import org.apache.turbine.om.security.*;
import org.apache.turbine.om.security.peer.*;
import org.apache.turbine.om.user.*;
import org.apache.turbine.om.user.peer.*;
import org.apache.turbine.util.db.*;
import org.apache.turbine.util.db.pool.*;
import com.workingdogs.village.*;
import org.apache.ecs.*;
import org.apache.ecs.html.*;

public class EditAccount extends Screen
{
    public ConcreteElement doBuild( RunData data ) throws Exception
    {
        // check to make sure the user has logged in before accessing this screen
        if ( ! data.getUser().hasLoggedIn() )
        {
            data.setMessage(Localization.getString("EDITACCOUNT_NOTLOGGEDIN"));
            return ScreenLoader.getInstance().eval ( data, "MainMenu" );
        }
        
        // set the title
        data.setTitle(Localization.getString("EDITACCOUNT_TITLE"));

        ElementContainer ec = new ElementContainer();
        
        // find the next screen
        String nextscreen = data.parameters.getString ( "nextscreen", null );
        if ( nextscreen == null || nextscreen.equals("EditAccount") )
            nextscreen = "MainMenu";

        Form form = new Form ( new DynamicURI ( data, nextscreen, "UpdateAccount", true ).toString()
            , Form.POST );

        form.addElement ( new Input ( Input.hidden, "nextscreen", nextscreen ));

        // fill in the blanks in the form
        String username = data.getUser().getUserName();
        String firstname = null;
        String lastname = null;
        String email = null;

        // for security, get information about the user from the database
        // instead of what we already have cached.
        Criteria crit = new Criteria();
        crit.add ( TurbineUserPeer.getColumnName("VISITORID"), data.getUser().getId() );        
        Vector output = TurbineUserPeer.doSelect(crit);
        if ( output.size() > 0 )
        {
            User user = (User) output.elementAt(0);
            firstname = (String) user.getPerm(TurbineUserPeer.FIRST_NAME);
            lastname = (String) user.getPerm(TurbineUserPeer.LAST_NAME);
            email = (String) user.getPerm(TurbineUserPeer.EMAIL);
            if ( firstname == null )
                firstname = "";
            if ( lastname == null )
                lastname = "";
            if ( email == null )
                email = "";
        }
        else // user information could not be found.
        {
            data.setMessage(Localization.getString("EDITACCOUNT_NOTLOGGEDIN"));
            return ScreenLoader.getInstance().eval ( data, "MainMenu" );
        }
        
        // display the table of information
        Table table = new Table().setCellSpacing(0).setCellPadding(0).setBorder(0);

        table.addElement ( new TR()
           .addElement ( new TD().addElement (Localization.getString("EDITACCOUNT_USERNAMEMSG"))
             .addElement ( new TD().addElement ( username ))));
        table.addElement ( new TR()
           .addElement ( new TD().addElement (Localization.getString("EDITACCOUNT_PASSWORDMSG"))
             .addElement ( new TD().addElement ( new Input(Input.PASSWORD, "password", "")))));
        table.addElement ( new TR()
           .addElement ( new TD().addElement (Localization.getString("EDITACCOUNT_PASSWORDCONFIRMMSG"))
             .addElement ( new TD().addElement ( new Input(Input.PASSWORD, "password_confirm", "")))));

        table.addElement ( new TR()
             .addElement ( new TD().addElement ( new HR().setSize(1).setNoShade(true) ).setColSpan(2) ));

        table.addElement ( new TR()
           .addElement ( new TD().addElement (Localization.getString("EDITACCOUNT_FIRSTNAMEMSG"))
             .addElement ( new TD().addElement ( new Input(Input.TEXT, "firstname", firstname )))));
        table.addElement ( new TR()
           .addElement ( new TD().addElement (Localization.getString("EDITACCOUNT_LASTNAMEMSG"))
             .addElement ( new TD().addElement ( new Input(Input.TEXT, "lastname", lastname )))));
        table.addElement ( new TR()
           .addElement ( new TD().addElement (Localization.getString("EDITACCOUNT_EMAILMSG"))
             .addElement ( new TD().addElement ( new Input(Input.TEXT, "email", email )))));

        String buta = "submit1";
        String butb = "submit2";
        String but1 = Localization.getString("EDITACCOUNT_CANCEL");
        String but2 = Localization.getString("EDITACCOUNT_CREATE");
        data.getUser().setTemp ( buta, but1 );
        data.getUser().setTemp ( butb, but2 );

        table.addElement ( new TR().addElement(
            new TD().addElement ( new Input ( Input.submit, buta, but1 ) )
            .addElement ( new Input ( Input.submit, butb, but2 ) )
                .setAlign(AlignType.right).setColSpan(2) ));

        form.addElement ( table );
        return ec.addElement (form);
    }
}
