package org.apache.jyve.screens;

/*
 * Copyright (c) 1997-1999 The Java Apache Project.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. All advertising materials mentioning features or use of this
 *    software must display the following acknowledgment:
 *    "This product includes software developed by the Java Apache
 *    Project for use in the Apache JServ servlet engine project
 *    <http://java.apache.org/>."
 *
 * 4. The names "Apache JServ", "Apache JServ Servlet Engine", "Jyve",
 *    "Apache Jyve", "Jyve Project", "Apache Jyve Project" and
 *    "Java Apache Project" must not be used to endorse or promote products
 *    derived from this software without prior written permission.
 *
 * 5. Products derived from this software may not be called "Apache JServ"
 *    nor may "Apache" nor "Apache JServ" appear in their names without
 *    prior written permission of the Java Apache Project.
 *
 * 6. Redistributions of any form whatsoever must retain the following
 *    acknowledgment:
 *    "This product includes software developed by the Java Apache
 *    Project for use in the Apache JServ servlet engine project
 *    <http://java.apache.org/>."
 *
 * THIS SOFTWARE IS PROVIDED BY THE JAVA APACHE PROJECT "AS IS" AND ANY
 * EXPRESSED OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE JAVA APACHE PROJECT OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Java Apache Group. For more information
 * on the Java Apache Project and the Apache JServ Servlet Engine project,
 * please see <http://java.apache.org/>.
 *
 */

// JDK Stuff
import java.sql.*;

// External Stuff
import org.apache.jyve.util.*;
import org.apache.turbine.modules.*;
import org.apache.turbine.services.*;
import org.apache.turbine.services.localization.*;
import org.apache.turbine.util.*;
import org.apache.turbine.om.security.*;
import org.apache.turbine.util.db.*;
import org.apache.turbine.util.db.pool.*;
import com.workingdogs.village.*;
import org.apache.ecs.*;
import org.apache.ecs.html.*;

public class EditAnswer extends Screen
{
    private static final String buta = "submit1";
    private static final String butb = "submit2";
    private static final String butc = "submit3";
    private static final String but1 = Localization.getString("EDITANSWER_CANCEL");
    private static final String but2 = Localization.getString("EDITANSWER_DELETE");
    private static final String but3 = Localization.getString("EDITANSWER_SAVE");

    public ConcreteElement doBuild( RunData data ) throws Exception
    {
        // get the related id's
        Integer question_id = (Integer) data.getUser().getTemp("question_id",
            data.getParameters().getInteger("question_id", -1 ) );
        if ( question_id == null || question_id.intValue() == -1 )
        {
            data.setMessage(Localization.getString("EDITANSWER_NOVALIDQUESTION"));
            return ScreenLoader.getInstance().eval ( data, "DisplayTopics" );
        }
        Integer answer_id = (Integer) data.getUser().getTemp("answer_id", 
            data.getParameters().getInteger("answer_id", -1 ) );
        if ( answer_id == null || answer_id.intValue() == -1 )
        {
            data.setMessage(Localization.getString("EDITANSWER_NOVALIDANSWER"));
            return ScreenLoader.getInstance().eval ( data, "DisplayTopics" );
        }

        // Security check. This feature was added at 26.01.2000
        // by Bernie Hoeneisen, ETH Zurich, mailto:bhoeneis@ee.ethz.ch
        // last modified: 22.02.2000 (bernie)
        JSecurityCheck secCheck = new JSecurityCheck(data, 
            Localization.getString("EDITANSWER_NOMODIFYPERM"), 
            "DisplayQuestionAnswer" );
        if ( !secCheck.accessToScreenEdit("answer", answer_id))
        {
            return ScreenLoader.getInstance().eval ( data, data.getScreen() );
        }

        // set the Title tag of the page
        data.setTitle(Localization.getString("EDITANSWER_TITLE"));
        
        // prepare the SQL query
        StringBuffer sql = new StringBuffer();
        sql.append ( "select " );
        sql.append ( " question.question_value" );
        sql.append ( " from" );
        sql.append ( " question" );
        sql.append ( " where" );
        sql.append ( " question.question_id=" );
        sql.append ( question_id );

        // get a connection to the db
        DBConnection db = DBBroker.getInstance().getConnection();
        Connection connection = db.getConnection();

        // execute the query
        QueryDataSet qds = new QueryDataSet( connection, sql.toString() );
        String question_value = null;
        String answer_value = null;
        String save_type = null;
        int display_order = 0;
        try
        {
            qds.fetchRecords(1);
            int size = qds.size();
            if ( size > 0 )
            {
                question_value = qds.getRecord(0).getValue("question_value").asString();
            }

            sql = new StringBuffer();
            sql.append ( "select " );
            sql.append ( " answer.answer_value, answer.savetype, answer.DISPLAY_ORDER" );
            sql.append ( " from" );
            sql.append ( " answer" );
            sql.append ( " where" );
            sql.append ( " answer.answer_id=" );
            sql.append ( answer_id );

            qds = new QueryDataSet( connection, sql.toString() );
            qds.fetchRecords(1);
            size = qds.size();
            
            if ( size > 0 )
            {
                answer_value = qds.getRecord(0).getValue("answer_value").asString();
                save_type = qds.getRecord(0).getValue("savetype").asString();
                display_order = qds.getRecord(0).getValue("display_order").asInt();
            }
        }
        finally
        {
            if ( qds != null ) qds.close();
            DBBroker.getInstance().releaseConnection(db);

        }

        Form form = new Form ( 
            new DynamicURI ( data, "DisplayQuestionAnswer", "UpdateAnswer", true )
            .toString()
            , Form.POST );

        form.addElement ( new Input ( Input.HIDDEN, "answer_id", answer_id ) );

        Table table = new Table().setBorder(0).setCellPadding(0).setCellSpacing(0);

        table.addElement ( new TR());
        table.addElement ( new TD( new H3(Localization.getString("EDITANSWER_CHANGEANSWERMSG"))).setColSpan(2) );
        table.addElement ( new TR());
        table.addElement ( new TD( new Font().addElement(question_value).setSize(3)).setColSpan(2) );

        table.addElement ( new TR());
        table.addElement ( new TD( 
            new TextArea("answer_value", 20, 80).setWrap(TextArea.VIRTUAL)
                .addElement(answer_value)).setColSpan(2));

        table.addElement ( new TR());
        Select se = new Select("savetype");
        Option o1 = new Option("Html").addElement("Html Text");
        Option o2 = new Option("Plain").addElement("Plain Text");
        if ( save_type.equalsIgnoreCase("H") )
        {
            o1.setSelected(true);
        }
        else
        {
            o2.setSelected(true);
        }
        
        se.addElement ( o1 );
        se.addElement ( o2 );
        table.addElement ( new TR().addElement(
            new TD(se).setColSpan(2).setAlign(AlignType.right) ));

        table.addElement ( new TR().addElement(
            new TD("&nbsp;").setColSpan(2).setAlign(AlignType.right)) );

        ElementContainer orderEC = new ElementContainer();
        orderEC.addElement (Localization.getString("EDITANSWER_ORDERNUMMSG"));
        orderEC.addElement ( new Input ( Input.text, "display_order", display_order ).setSize(5) );        
        table.addElement ( new TR().addElement(
            new TD(orderEC).setColSpan(2).setAlign(AlignType.right)) );
        
        table.addElement ( new TR().addElement(
            new TD("&nbsp;").setColSpan(2).setAlign(AlignType.right)) );
        
        table.addElement ( new TR().addElement(
            new TD().addElement ( new Input ( Input.submit, buta, but1 ) )
            .addElement ( new Input ( Input.submit, butb, but2 ) )
            .addElement ( new Input ( Input.submit, butc, but3 ) )
                .setAlign(AlignType.right).setColSpan(2) ));

        data.getUser().setTemp ( buta, but1 );
        data.getUser().setTemp ( butb, but2 );
        data.getUser().setTemp ( butc, but3 );

        form.addElement(table);
        return form;
    }
}
