package org.apache.jyve.screens;

/*
 * Copyright (c) 1997-1999 The Java Apache Project.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. All advertising materials mentioning features or use of this
 *    software must display the following acknowledgment:
 *    "This product includes software developed by the Java Apache
 *    Project for use in the Apache JServ servlet engine project
 *    <http://java.apache.org/>."
 *
 * 4. The names "Apache JServ", "Apache JServ Servlet Engine", "Jyve",
 *    "Apache Jyve", "Jyve Project", "Apache Jyve Project" and
 *    "Java Apache Project" must not be used to endorse or promote products
 *    derived from this software without prior written permission.
 *
 * 5. Products derived from this software may not be called "Apache JServ"
 *    nor may "Apache" nor "Apache JServ" appear in their names without
 *    prior written permission of the Java Apache Project.
 *
 * 6. Redistributions of any form whatsoever must retain the following
 *    acknowledgment:
 *    "This product includes software developed by the Java Apache
 *    Project for use in the Apache JServ servlet engine project
 *    <http://java.apache.org/>."
 *
 * THIS SOFTWARE IS PROVIDED BY THE JAVA APACHE PROJECT "AS IS" AND ANY
 * EXPRESSED OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE JAVA APACHE PROJECT OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Java Apache Group. For more information
 * on the Java Apache Project and the Apache JServ Servlet Engine project,
 * please see <http://java.apache.org/>.
 *
 */

// JDK Stuff
import java.sql.*;

// External Stuff
import org.apache.jyve.util.*;
import org.apache.turbine.modules.*;
import org.apache.turbine.services.localization.Localization;
import org.apache.turbine.services.resources.TurbineResources;
import org.apache.turbine.util.*;
import org.apache.turbine.om.security.*;
import org.apache.turbine.util.db.*;
import org.apache.turbine.util.db.pool.*;
import com.workingdogs.village.*;
import org.apache.ecs.*;
import org.apache.ecs.html.*;

public class SearchResults extends Screen
{
    public ConcreteElement doBuild( RunData data ) throws Exception
    {
        data.setTitle(Localization.getString("SEARCHRESULTS_TITLE"));

        JSecurityCheck secCheck = new JSecurityCheck(data);
        boolean showUnreleasedProject =
            ( secCheck.permissionToRelease("project") )
            || ( secCheck.permissionToSeeUnreleased("project") );
        boolean showUnreleasedFaq =
            ( secCheck.permissionToRelease("faq") )
            || ( secCheck.permissionToSeeUnreleased("faq") );
        boolean showUnreleasedTopic =
            ( secCheck.permissionToRelease("topic") )
            || ( secCheck.permissionToSeeUnreleased("topic") );
        boolean showUnreleasedQuestion =
            ( secCheck.permissionToRelease("question") )
            || ( secCheck.permissionToSeeUnreleased("question") );
        boolean showUnreleasedAnswer =
            ( secCheck.permissionToRelease("answer") )
            || ( secCheck.permissionToSeeUnreleased("answer") );
        int visitorId = data.getUser().getId();
        
        ElementContainer ec = new ElementContainer();
        ec.addElement ( ScreenLoader.getInstance().eval ( data, "SearchGlobal" ) );
        ec.addElement ( new HR().setSize(1).setNoShade(true));
        
        ec.addElement (new B(Localization.getString("SEARCHRESULTS_SEARCHRESULTMSG")) );
        ec.addElement ( new P() );
        
        String search = data.parameters.getString("search", null );
        if ( search == null || search.length() == 0 )
        {
            data.setMessage (Localization.getString("SEARCHRESULTS_NOVALIDSEARCH"));
            data.setScreen ("SearchGlobal");
        }
        
        // get a connection to the db
        DBConnection db = DBBroker.getInstance().getConnection();
        Connection connection = db.getConnection();
        
        StringBuffer sql = new StringBuffer();
        sql.append ( "select distinct" );
        sql.append ( " p.project_id, p.project_value " );
        sql.append ( ", f.faq_id, f.faq_value " );
        sql.append ( ", t.topic_id, t.topic_value " );
        sql.append ( ", q.question_id, q.question_value " );
        // sql.append ( ", a.answer_id, a.answer_value " );
        // sql.append ( ", p.deleted, f.deleted " );
        // sql.append ( ", t.deleted, q.deleted " );
        // sql.append ( ", a.deleted " );
        sql.append ( ", p.released as project_released, f.released as faq_released" );
        sql.append ( ", t.released as topic_released, q.released as question_released" );
        
        sql.append ( " from " );
        sql.append ( " project p, faq f, topic t, question q, answer a " );

        sql.append ( " where " );
        sql.append ( " p.project_id=f.project_id " );
        sql.append ( " and " );
        sql.append ( " f.faq_id=t.faq_id " );
        sql.append ( " and " );
        sql.append ( " t.topic_id=q.topic_id " );
        sql.append ( " and " );
        sql.append ( " q.question_id=a.question_id " );

        sql.append ( " and " );
        sql.append ( " p.deleted='N' " );
        sql.append ( " and " );
        sql.append ( " f.deleted='N' " );
        sql.append ( " and " );
        sql.append ( " t.deleted='N' " );
        sql.append ( " and " );
        sql.append ( " q.deleted='N' " );
        sql.append ( " and " );
        sql.append ( " a.deleted='N' " );

        if (!showUnreleasedProject)
        {
            // select if the project is released or it was created by the current visitor
            sql.append ( "AND ( p.released='Y' OR p.visitorid=");
            sql.append ( visitorId );
            sql.append ( ")");
        }

        if (!showUnreleasedFaq)
        {
            // select if the faq is released or it was created by the current visitor
            sql.append ( "AND ( f.released='Y' OR f.visitorid=");
            sql.append ( visitorId );
            sql.append ( ")");
        }
        
        if (!showUnreleasedTopic)
        {
            // select if the topic is released or it was created by the current visitor
            sql.append ( "AND ( t.released='Y' OR t.visitorid=");
            sql.append ( visitorId );
            sql.append ( ")");
        }

        if (!showUnreleasedQuestion)
        {
            // select if the question is released or it was created by the current visitor
            sql.append ( "AND ( q.released='Y' OR q.visitorid=");
            sql.append ( visitorId );
            sql.append ( ")");
        }

        if (!showUnreleasedAnswer)
        {
            // select if the answer is released or it was created by the current visitor
            sql.append ( "AND ( a.released='Y' OR a.visitorid=");
            sql.append ( visitorId );
            sql.append ( ")");
        }

        sql.append ( " and " );
        sql.append ( " (p.project_value LIKE '%" );
        sql.append ( search );
        sql.append ( "%' " );
        sql.append ( " OR " );
        sql.append ( " t.topic_value LIKE '%" );
        sql.append ( search );
        sql.append ( "%' " );
        sql.append ( " OR " );
        sql.append ( " f.faq_value LIKE '%" );
        sql.append ( search );
        sql.append ( "%' " );
        sql.append ( " OR " );
        sql.append ( " q.question_value LIKE '%" );
        sql.append ( search );
        sql.append ( "%' " );
        sql.append ( " OR " );
        sql.append ( " a.answer_value LIKE '%" );
        sql.append ( search );
        sql.append ( "%')" );
        
        // execute the query
        QueryDataSet qds = new QueryDataSet( connection, sql.toString());

        String colorRowTitle = TurbineResources.
            getString("jyve.display.color.row.title");
        String colorRowUnreleased = TurbineResources.
            getString("jyve.display.color.row.unreleased");
        String colorTableBackground = TurbineResources.
            getString("jyve.display.color.table.background");
        
        int size = 0;
        try
        {
            qds.fetchRecords();
            size = qds.size();
            if ( size > 0 )
            {
                Table table = new Table().setBorder(0).setCellPadding(5).
                    setBgColor(colorTableBackground);
                TR top = new TR().setBgColor(colorRowTitle);
                top.addElement ( new TD().addElement (
                     new Font().addElement(Localization.getString("SEARCHRESULTS_PROJECTMSG")).setColor(HtmlColor.white).setSize(4) )
                    );
                top.addElement ( new TD().addElement ( 
                     new Font().addElement(Localization.getString("SEARCHRESULTS_FAQMSG")).setColor(HtmlColor.white).setSize(4) )
                    );
                top.addElement ( new TD().addElement ( 
                     new Font().addElement(Localization.getString("SEARCHRESULTS_TOPICMSG")).setColor(HtmlColor.white).setSize(4) )
                    );
                top.addElement ( new TD().addElement ( 
                     new Font().addElement(Localization.getString("SEARCHRESULTS_QUESTIONMSG")).setColor(HtmlColor.white).setSize(4) )
                    );
                table.addElement ( top );
                for ( int i=0;i<size;i++ )
                {
                    String project_value = qds.getRecord(i).getValue("project_value").asString();
                    String faq_value = qds.getRecord(i).getValue("faq_value").asString();
                    String topic_value = qds.getRecord(i).getValue("topic_value").asString();
                    String question_value = qds.getRecord(i).getValue("question_value").asString();
                    int project_id = qds.getRecord(i).getValue("project_id").asInt();
                    int faq_id = qds.getRecord(i).getValue("faq_id").asInt();
                    int topic_id = qds.getRecord(i).getValue("topic_id").asInt();
                    int question_id = qds.getRecord(i).getValue("question_id").asInt();
                    
                    DynamicURI pduri = new DynamicURI(data, "DisplayProjects", "SetAll")
                        .addPathInfo("project_id", project_id );
                    DynamicURI fduri = new DynamicURI(data, "DisplayFaqs", "SetAll")
                        .addPathInfo("project_id", project_id )
                        .addPathInfo("faq_id", faq_id );
                    DynamicURI tduri = new DynamicURI(data, "DisplayTopics", "SetAll")
                        .addPathInfo("project_id", project_id )
                        .addPathInfo("faq_id", faq_id )
                        .addPathInfo("topic_id", topic_id );
                    DynamicURI qduri = new DynamicURI(data, "DisplayQuestionAnswer", "SetAll")
                        .addPathInfo("project_id", project_id )
                        .addPathInfo("faq_id", faq_id )
                        .addPathInfo("topic_id", topic_id )
                        .addPathInfo("question_id", question_id );

                    TR tr = new TR();

                    TD tdP = new TD();
                    tdP.addElement ( new A()
                        .addElement(project_value).setHref ( pduri.toString() ) );
                    if ( !qds.getRecord(i).getValue("project_released").asString().equalsIgnoreCase("Y"))
                         tdP.setBgColor(colorRowUnreleased);
                    tr.addElement ( tdP );

                    TD tdF = new TD();
                    tdF.addElement ( new A()
                        .addElement(faq_value).setHref ( fduri.toString() ) );
                    if ( !qds.getRecord(i).getValue("faq_released").asString().equalsIgnoreCase("Y"))
                         tdF.setBgColor(colorRowUnreleased);                    
                    tr.addElement ( tdF );

                    TD tdT = new TD();
                    tdT.addElement ( new A()
                        .addElement(topic_value).setHref ( tduri.toString() ) );
                    if ( !qds.getRecord(i).getValue("topic_released").asString().equalsIgnoreCase("Y"))
                         tdT.setBgColor(colorRowUnreleased);                    
                    tr.addElement ( tdT );

                    TD tdQ = new TD();
                    tdQ.addElement ( new A()
                        .addElement(question_value).setHref ( qduri.toString() ) );
                    if ( !qds.getRecord(i).getValue("question_released").asString().equalsIgnoreCase("Y"))
                         tdQ.setBgColor(colorRowUnreleased);                    
                    tr.addElement ( tdQ );
                    
                    table.addElement ( tr );
                }
                ec.addElement ( table );
            }
            else
            {
                // Logging the keywords which were not found
                Log.note("Keyword not found in search: " + search);
                data.setMessage (Localization.getString("SEARCHRESULTS_NOMATCHMSG"));
                return ScreenLoader.getInstance().eval ( data, "SearchGlobal" );
            }
        }
        finally
        {
            if ( qds != null ) qds.close();
            DBBroker.getInstance().releaseConnection(db);
        }
        ec.addElement ( new P());
        ec.addElement ( Localization.getString("SEARCHRESULTS_TOTALMSG") + size );
        ec.addElement ( new P());
        
        return ec;
    }
}
