package org.apache.jyve.util;

/*
 * Copyright (c) 1997-1999 The Java Apache Project.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. All advertising materials mentioning features or use of this
 *    software must display the following acknowledgment:
 *    "This product includes software developed by the Java Apache
 *    Project for use in the Apache JServ servlet engine project
 *    <http://java.apache.org/>."
 *
 * 4. The names "Apache JServ", "Apache JServ Servlet Engine", "Jyve",
 *    "Apache Jyve", "Jyve Project", "Apache Jyve Project" and
 *    "Java Apache Project" must not be used to endorse or promote products
 *    derived from this software without prior written permission.
 *
 * 5. Products derived from this software may not be called "Apache JServ"
 *    nor may "Apache" nor "Apache JServ" appear in their names without
 *    prior written permission of the Java Apache Project.
 *
 * 6. Redistributions of any form whatsoever must retain the following
 *    acknowledgment:
 *    "This product includes software developed by the Java Apache
 *    Project for use in the Apache JServ servlet engine project
 *    <http://java.apache.org/>."
 *
 * THIS SOFTWARE IS PROVIDED BY THE JAVA APACHE PROJECT "AS IS" AND ANY
 * EXPRESSED OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE JAVA APACHE PROJECT OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Java Apache Group. For more information
 * on the Java Apache Project and the Apache JServ Servlet Engine project,
 * please see <http://java.apache.org/>.
 *
 */

import java.util.*;
import java.io.*;

/**
    This class is for generating the users and roles/permissions for
    the jyve system. It will generate a bunch of SQL and output it to 
    a file.
    
    @author Jon S. Stevens <a href="mailto:jon@latchkey.com">jon@latchkey.com</a>
*/
public class GenerateRights
{
    private static File headerFile = null;
    private static File permissionsFile = null;
    private static File usersFile = null;
    private static File outputFile = null;
    
    private static StringBuffer output = new StringBuffer(2048);
    
    private static boolean DEBUG = false;
    
    /** the main execution of this class */
    public static void main(String[] args)
    {
        try
        {
            if ( DEBUG )
            {
                args = new String[8];
                args[0] = "-headerFile";
                args[1] = "e:/projects/jyve/docs/header_jyve_access_rights";
                args[2] = "-permissionsFile";
                args[3] = "e:/projects/jyve/docs/jyve_permissions_roles";
                args[4] = "-usersFile";
                args[5] = "e:/projects/jyve/docs/jyve_users_roles";
                args[6] = "-outputFile";
                args[7] = "e:/projects/jyve/docs/Generated_MySQL_Schema.sql";
            }
            
            System.out.println ("Processing...\n");
            // processing
            getArgs(args);
            processHeaderFile();
            processUsersFile();
            processPermissionsFile();
            
            // output
            writeOutput();
            
            System.out.println ("\nMySQL insert script successfully written!");
            System.out.println ("Please have a look on the syntax before you run it!\n");
        }
        catch (Exception e)
        {
            System.out.println ( "Error: " + e.toString() + "\n");
            printUsage();
        }
    }
    /** write the output stringbuffer to a file */
    private static void writeOutput()
        throws Exception
    {
        FileWriter fileOut = new FileWriter( outputFile.toString() );
        fileOut.write(output.toString());
        fileOut.flush();
        fileOut.close();
    }
    /** read in the header file and append it to the output */
    private static void processHeaderFile()
        throws Exception
    {
        output.append ( "### ------------------ HEADER FILE BEGIN ------------------ ###\n" );
        // read this file a line at a time to deal with
        // line endings on different platforms
        String line = "";
        BufferedReader br = new BufferedReader(new FileReader(headerFile));
        do
        {
            output.append ( line + "\n" );
        }
        while ( (line = br.readLine()) != null );
        br.close();
        output.append ( "### ------------------ HEADER FILE END ------------------ ###\n" );
    }
    /** parse the users file and generate the necessary SQL output */
    private static void processUsersFile()
        throws Exception
    {
        // read the file
        BufferedReader br = new BufferedReader(new FileReader(usersFile));
        String line = "";
        do
        {
            // skip blank lines
            if ( line == null || line.length() == 0 || checkComment(line) )
                continue;
            
            // append the original line as comment
            output.append ( "\n#" + line + "\n" );
            // split the string on ":"
            String[] data = splitString(line, ":");
            // should have only 3 items in the array
            if ( data.length != 3 )
            {
                throw new Exception ( "1: Parser Error in processUsersFile() line: " + line );
            }
            // create insert for visitor
            output.append("insert into Visitor (LOGINID, PASSWORD_VALUE, " + 
                "CONFIRM_VALUE, MODIFIED, CREATED ) values ('" + 
                data[0] + "', '" + data[1] + "', 'CONFIRMED', null, null );\n");
            
            // split up the roles
            String[] roles = splitString(data[2],",");
            if ( roles.length == 0 )
            {
                throw new Exception ( "2: Parser Error in processUsersFile() line: " + data[2] );
            }
            // create an insert for visitor to role mapping
            for (int i =0;i<roles.length;i++)
            {
                output.append ("insert into VisitorRole ( VISITORID, ROLEID ) select " + 
                    "Visitor.VISITORID, UserRole.RoleID from Visitor, UserRole where Visitor.loginid = " + 
                    "'" + data[0] + "' AND UserRole.rolename = '" + roles[i] + "';\n");
            }
        }
        while ( (line = br.readLine()) != null );
        br.close();
    }
    /** parse the permissions file and generate the necessary SQL output */
    private static void processPermissionsFile()
        throws Exception
    {
        // read the file
        BufferedReader br = new BufferedReader(new FileReader(permissionsFile));
        String line = "";
        do
        {
            // skip blank lines
            if ( line == null || line.length() == 0 || checkComment(line) )
                continue;

            // append the original line as comment
            output.append ( "\n#" + line + "\n" );
                
            // split the string on ":"
            String[] data = splitString(line, ":");
            // should have only 2 items in the array
            if ( data.length != 2 )
            {
                throw new Exception ( "1: Parser Error in processPermissionsFile() line: " + line );
            }
            // add permissions
            output.append("insert into Permission (PERMISSION) values ('" + data[0] + "');\n");
            // split up the roles
            String[] roles = splitString(data[1],",");
            if ( roles.length == 0 )
            {
                throw new Exception ( "2: Parser Error in processUsersFile() line: " + data[1] );
            }
            // create an insert for visitor to role mapping
            for (int i =0;i<roles.length;i++)
            {
                output.append ("insert into RolePermission (ROLEID,PERMISSIONID) select " +
                    "UserRole.ROLEID, Permission.PERMISSIONID from UserRole, Permission where " + 
                    "Permission.PERMISSION='" + data[0] + "' and UserRole.ROLENAME='" + roles[i] + "';\n");
            }
        }
        while ( (line = br.readLine()) != null );
        br.close();
    }
    /** see if a string starts with a # */
    private static boolean checkComment(String str)
    {
        if ( str.startsWith("#"))
            return true;
        return false;
    }
    /** split a string based on the delim and return a String[] */
    private static String[] splitString (String str, String delim)
    {
        StringTokenizer st = new StringTokenizer(str, delim);
        String[] data = new String[st.countTokens()];
        int count = 0;
        while ( st.hasMoreTokens() )
        {
            data[count] = st.nextToken().trim();
            count++;
        }
        return data;
    }
    /** get and process the arguments passed in on the command line */
    private static void getArgs(String[] args)
        throws Exception
    {
        if (args.length != 8)
        {
            throw new Exception ( "Invalid number of arguments: " + args.length + " should be 8" );
        }
        
        for (int i = 0; i < args.length; i++)
        {
            String arg = args[i];
            if ( arg == null )
                break;
                
            if ( arg.equals ("-headerFile" ) )
            {
                LOG("headerFile: " + args[i+1]);                
                headerFile = new File(args[i+1]);
                checkFileExists(headerFile);
                i++;
            }
            else if ( arg.equals("-permissionsFile" ) )
            {
                LOG("permissionsFile: " + args[i+1]);                
                permissionsFile = new File(args[i+1]);
                checkFileExists(permissionsFile);
                i++;
            }
            else if ( arg.equals("-usersFile" ) )
            {
                LOG("usersFile: " + args[i+1]);                
                usersFile = new File(args[i+1]);
                checkFileExists(usersFile);
                i++;
            }
            else if ( arg.equals("-outputFile" ) )
            {
                LOG("outputFile: " + args[i+1]);                
                outputFile = new File(args[i+1]);
                i++;
            }
        }
    }
    /** prints the usage */
    private static void printUsage()
    {
        System.out.println ( "Usage: GenerateRights -headerFile file -permissionsFile file -usersFile file -outputFile file" );
        System.out.println ( "" );
        System.out.println ( "-headerFile file      : This is the file that gets prepended to the output" );
        System.out.println ( "-permissionsFile file : Contains the roles/permissions mapping" );
        System.out.println ( "-usersFile file       : Contains the users/roles mapping" );
        System.out.println ( "-outputFile file      : File where the output is sent\n" );
        System.out.println ( "    *\"file\" == the absolute path to the file on disk\n" );
    }
    
    /** stupid logging facility */
    private static void LOG ( String msg )
    {
        System.out.println ( msg );
    }
    /** check to see if a file exists and it is readable */
    private static void checkFileExists(File file)
        throws Exception
    {
        if (!file.exists() || !file.canRead())
        {
            throw new Exception ("File: " + file + " does not exist!");
        }
        else if (!file.canRead())
        {
            throw new Exception ("File: " + file + " cannot be read!");
        }
    }
}