package org.apache.jyve.util;

/*
 * Copyright (c) 1997-1999 The Java Apache Project.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. All advertising materials mentioning features or use of this
 *    software must display the following acknowledgment:
 *    "This product includes software developed by the Java Apache
 *    Project for use in the Apache JServ servlet engine project
 *    <http://java.apache.org/>."
 *
 * 4. The names "Apache JServ", "Apache JServ Servlet Engine", "Jyve",
 *    "Apache Jyve", "Jyve Project", "Apache Jyve Project" and
 *    "Java Apache Project" must not be used to endorse or promote products
 *    derived from this software without prior written permission.
 *
 * 5. Products derived from this software may not be called "Apache JServ"
 *    nor may "Apache" nor "Apache JServ" appear in their names without
 *    prior written permission of the Java Apache Project.
 *
 * 6. Redistributions of any form whatsoever must retain the following
 *    acknowledgment:
 *    "This product includes software developed by the Java Apache
 *    Project for use in the Apache JServ servlet engine project
 *    <http://java.apache.org/>."
 *
 * THIS SOFTWARE IS PROVIDED BY THE JAVA APACHE PROJECT "AS IS" AND ANY
 * EXPRESSED OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE JAVA APACHE PROJECT OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Java Apache Group. For more information
 * on the Java Apache Project and the Apache JServ Servlet Engine project,
 * please see <http://java.apache.org/>.
 *
 */

// JDK Stuff
import java.io.*;
import java.sql.*;
import java.util.*;
 
// External Stuff
import org.apache.turbine.util.*;
import org.apache.turbine.util.db.*;
import org.apache.turbine.util.db.pool.*;
import com.workingdogs.village.*;

/** This class has been added 15.02.2000 by Bernie Hoeneisen, ETH Zurich
 *  <a href="mailto:bhoeneis@ee.ethz.ch">bhoeneis@ee.ethz.ch</a>
 *  It is meant for extracting certain information from Jyve tables. 
 *  @author <a href="mailto:bhoeneis@ee.ethz.ch"> Bernie H&ouml;neisen</a>, ETH Zurich
 */
public class RecordExtractor
{

    private RunData data = null;

    /** 
     *  Constructor
     */
    public RecordExtractor(RunData data) 
    {
        this.data = data;
    }
    
    /**
     *  get the VISITORID of a record in the Jyve database using
     *  the name of table and a unique id of the record belonging to it.  
     *  @author Bernie Hoeneisen, ETH Zurich, mailto:bhoeneis@ee.ethz.ch
     */ 

    public int getVisitorId ( String tablename, Integer idValue) throws Exception
    {

        // prepare SQL query
        StringBuffer sql = new StringBuffer();
        sql.append ( "select " );
        sql.append ( tablename );
        sql.append ( ".VISITORID " );
        sql.append ( "from " );
        sql.append ( tablename );
        sql.append ( " where " );
        sql.append ( tablename );
        sql.append ( "." );
        sql.append ( tablename );
        sql.append ( "_id=" );
        sql.append ( idValue.toString() );

        // get a connection to the db
        DBConnection db = DBBroker.getInstance().getConnection();
        Connection connection = db.getConnection();

        // execute the query
        QueryDataSet qds = new QueryDataSet( connection, sql.toString() );
        int visitorId = 0;
        try
        {
            qds.fetchRecords(1);
            int size = qds.size();
            if ( size > 0 )
            {
                visitorId = qds.getRecord(0).getValue("VISITORID").asInt();
            }            
        }
        finally
        {
            if ( qds != null ) qds.close();
            DBBroker.getInstance().releaseConnection(db);

        }
        return visitorId;
    }
    
    /**
     *  get the RELEASED field of a record in the Jyve database using
     *  the name of table and a unique id of the record belonging to it.
     *  @param tablename project, faq, topic, question or answer
     *  @param idValue corresponding id of the record in <i>tablename</i> (e.g topic_id)
     *  @return value from the RELEASE column  
     *  @author Bernie Hoeneisen, ETH Zurich, mailto:bhoeneis@ee.ethz.ch
     */ 

    public String getReleasedValue ( String tablename, Integer idValue) throws Exception
    {

        // prepare SQL query
        StringBuffer sql = new StringBuffer();
        sql.append ( "select " );
        sql.append ( tablename );
        sql.append ( ".RELEASED " );
        sql.append ( "from " );
        sql.append ( tablename );
        sql.append ( " where " );
        sql.append ( tablename );
        sql.append ( "." );
        sql.append ( tablename );
        sql.append ( "_id=" );
        sql.append ( idValue.toString() );

        // get a connection to the db
        DBConnection db = DBBroker.getInstance().getConnection();
        Connection connection = db.getConnection();

        // execute the query
        QueryDataSet qds = new QueryDataSet( connection, sql.toString() );
        String releasedValue = null;
        try
        {
            qds.fetchRecords(1);
            int size = qds.size();
            if ( size > 0 )
            {
                releasedValue = qds.getRecord(0).getValue("RELEASED").asString();
            }            
        }
        finally
        {
            if ( qds != null ) qds.close();
            DBBroker.getInstance().releaseConnection(db);

        }
        return releasedValue;
    }
    /**
     *  get the CONFIRM_VALUE field out of the table Visitor in the Jyve database
     *  @param username LOGINID
     *  @return corresponding CONFIRM_VALUE  
     *  @author Bernie Hoeneisen, ETH Zurich, mailto:bhoeneis@ee.ethz.ch
     */ 

    public String getConfirmValue ( String username ) throws Exception
    {

        // prepare SQL query
        StringBuffer sql = new StringBuffer();
        sql.append ( "SELECT CONFIRM_VALUE FROM Visitor WHERE LOGINID='" );
        sql.append ( username );
        sql.append ( "';" );

        // get a connection to the db
        DBConnection db = DBBroker.getInstance().getConnection();
        Connection connection = db.getConnection();

        // execute the query
        QueryDataSet qds = new QueryDataSet( connection, sql.toString() );
        String confirmValue = null;
        try
        {
            qds.fetchRecords(1);
            int size = qds.size();
            if ( size > 0 )
            {
                confirmValue = qds.getRecord(0).getValue("CONFIRM_VALUE").asString();
            }            
        }
        finally
        {
            if ( qds != null ) qds.close();
            DBBroker.getInstance().releaseConnection(db);

        }
        return confirmValue;
    }

    /**
     *  get the RELEASED field of a record in the Jyve database using
     *  the name of table and a unique id of the record belonging to it.  
     *  @param tablename project, faq, topic, question or answer
     *  @param idValue corresponding id of the record in <i>tablename</i> (e.g topic_id)
     *  @return true if released, else false
     *  @author Bernie Hoeneisen, ETH Zurich, mailto:bhoeneis@ee.ethz.ch
     */
    public boolean isReleased ( String tablename, Integer idValue) throws Exception
    {
        if (getReleasedValue ( tablename, idValue ).equalsIgnoreCase("Y"))
            return true;

        return false;
    }

}
